pub struct CallResult<T> {
pub message_id: MessageId,
pub payload: T,
}Expand description
An OCPP-J CALLRESULT: [3, "<MessageId>", {Payload}]. Unlike
Call, there’s no action name on the wire – the recipient already
knows which action a result is for by correlating message_id against
the Call it sent, which is exactly what choosing T here represents.
Fields
message_id: MessageIdpayload: TTrait Implementations
Sourceimpl<T: Clone> Clone for CallResult<T>
impl<T: Clone> Clone for CallResult<T>
Sourcefn clone(&self) -> CallResult<T>
fn clone(&self) -> CallResult<T>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T: Debug> Debug for CallResult<T>
impl<T: Debug> Debug for CallResult<T>
Sourceimpl<'de, T: Deserialize<'de>> Deserialize<'de> for CallResult<T>
Available on crate feature serde only.
impl<'de, T: Deserialize<'de>> Deserialize<'de> for CallResult<T>
Available on crate feature
serde only.Sourcefn deserialize<D: Deserializer<'de>>(deserializer: D) -> Result<Self, D::Error>
fn deserialize<D: Deserializer<'de>>(deserializer: D) -> Result<Self, D::Error>
Deserialize this value from the given Serde deserializer. Read more
impl<T: Eq> Eq for CallResult<T>
Sourceimpl<T: PartialEq> PartialEq for CallResult<T>
impl<T: PartialEq> PartialEq for CallResult<T>
Sourceimpl<T: Serialize> Serialize for CallResult<T>
Available on crate feature serde only.
impl<T: Serialize> Serialize for CallResult<T>
Available on crate feature
serde only.impl<T: PartialEq> StructuralPartialEq for CallResult<T>