Module common

Module common 

Structs

ACChargingParameters
AC_ Charging_ Parameters urn:x-oca:ocpp:uid:2:233250 EV AC charging parameters.
APN
APN urn:x-oca:ocpp:uid:2:233134 Collection of configuration data needed to make a data-connection over a cellular network.
AdditionalInfo
Contains a case insensitive identifier to use for the authorization and the type of authorization to support multiple forms of identifiers.
AuthorizationData
Contains the identifier to use for authorization.
CertificateHashData
CertificateHashDataChain
ChargingLimit
Charging_ Limit urn:x-enexis:ecdm:uid:2:234489
ChargingNeeds
Charging_ Needs urn:x-oca:ocpp:uid:2:233249
ChargingProfile
Charging_ Profile urn:x-oca:ocpp:uid:2:233255 A ChargingProfile consists of ChargingSchedule, describing the amount of power or current that can be delivered per time interval.
ChargingProfileCriterion
Charging_ Profile urn:x-oca:ocpp:uid:2:233255 A ChargingProfile consists of ChargingSchedule, describing the amount of power or current that can be delivered per time interval.
ChargingSchedule
Charging_ Schedule urn:x-oca:ocpp:uid:2:233256 Charging schedule structure defines a list of charging periods, as used in: GetCompositeSchedule.conf and ChargingProfile.
ChargingSchedulePeriod
Charging_ Schedule_ Period urn:x-oca:ocpp:uid:2:233257 Charging schedule period structure defines a time period in a charging schedule.
ChargingStation
Charge_ Point urn:x-oca:ocpp:uid:2:233122 The physical system where an Electrical Vehicle (EV) can be charged.
ClearChargingProfile
Charging_ Profile urn:x-oca:ocpp:uid:2:233255 A ChargingProfile consists of a ChargingSchedule, describing the amount of power or current that can be delivered per time interval.
ClearMonitoringResult
Component
A physical or logical component
ComponentVariable
Class to report components, variables and variable attributes and characteristics.
CompositeSchedule
Composite_ Schedule urn:x-oca:ocpp:uid:2:233362
ConsumptionCost
Consumption_ Cost urn:x-oca:ocpp:uid:2:233259
Cost
Cost urn:x-oca:ocpp:uid:2:233258
CustomData
This class does not get ‘AdditionalProperties = false’ in the schema generation, so it can be extended with arbitrary JSON properties to allow adding custom data.
DCChargingParameters
DC_ Charging_ Parameters urn:x-oca:ocpp:uid:2:233251 EV DC charging parameters
EVSE
EVSE urn:x-oca:ocpp:uid:2:233123 Electric Vehicle Supply Equipment
EventData
Class to report an event notification for a component-variable.
Firmware
Firmware urn:x-enexis:ecdm:uid:2:233291 Represents a copy of the firmware that can be loaded/updated on the Charging Station.
GetVariableData
Class to hold parameters for GetVariables request.
GetVariableResult
Class to hold results of GetVariables request.
IdToken
Contains a case insensitive identifier to use for the authorization and the type of authorization to support multiple forms of identifiers.
IdTokenInfo
ID_ Token urn:x-oca:ocpp:uid:2:233247 Contains status information about an identifier. It is advised to not stop charging for a token that expires during charging, as ExpiryDate is only used for caching purposes. If ExpiryDate is not given, the status has no end date.
LogParameters
Log urn:x-enexis:ecdm:uid:2:233373 Generic class for the configuration of logging entries.
MessageContent
Message_ Content urn:x-enexis:ecdm:uid:2:234490 Contains message details, for a message to be displayed on a Charging Station.
MessageInfo
Message_ Info urn:x-enexis:ecdm:uid:2:233264 Contains message details, for a message to be displayed on a Charging Station.
MeterValue
Meter_ Value urn:x-oca:ocpp:uid:2:233265 Collection of one or more sampled values in MeterValuesRequest and TransactionEvent. All sampled values in a MeterValue are sampled at the same point in time.
Modem
Wireless_ Communication_ Module urn:x-oca:ocpp:uid:2:233306 Defines parameters required for initiating and maintaining wireless communication with other devices.
MonitoringData
Class to hold parameters of SetVariableMonitoring request.
NetworkConnectionProfile
Communication_ Function urn:x-oca:ocpp:uid:2:233304 The NetworkConnectionProfile defines the functional and technical parameters of a communication link.
OCSPRequestData
RelativeTimeInterval
Relative_ Timer_ Interval urn:x-oca:ocpp:uid:2:233270
ReportData
Class to report components, variables and variable attributes and characteristics.
SalesTariff
Sales_ Tariff urn:x-oca:ocpp:uid:2:233272 NOTE: This dataType is based on dataTypes from <<ref-ISOIEC15118-2,ISO 15118-2>>.
SalesTariffEntry
Sales_ Tariff_ Entry urn:x-oca:ocpp:uid:2:233271
SampledValue
Sampled_ Value urn:x-oca:ocpp:uid:2:233266 Single sampled value in MeterValues. Each value can be accompanied by optional fields.
SetMonitoringData
Class to hold parameters of SetVariableMonitoring request.
SetMonitoringResult
Class to hold result of SetVariableMonitoring request.
SetVariableData
SetVariableResult
SignedMeterValue
Represent a signed version of the meter value.
StatusInfo
Element providing more information about the status.
Transaction
Transaction urn:x-oca:ocpp:uid:2:233318
UnitOfMeasure
Represents a UnitOfMeasure with a multiplier
VPN
VPN urn:x-oca:ocpp:uid:2:233268 VPN Configuration settings
Variable
Reference key to a component-variable.
VariableAttribute
Attribute data of a variable.
VariableCharacteristics
Fixed read-only parameters of a variable.
VariableMonitoring
A monitoring setting for a variable.

Enums

APNAuthenticationEnum
APN. APN_ Authentication. APN_ Authentication_ Code urn:x-oca:ocpp:uid:1:568828 Authentication method.
AttributeEnum
Attribute type for which value is requested. When absent, default Actual is assumed.
AuthorizationStatusEnum
ID_ Token. Status. Authorization_ Status urn:x-oca:ocpp:uid:1:569372 Current status of the ID Token.
AuthorizeCertificateStatusEnum
Certificate status information.
BootReasonEnum
This contains the reason for sending this message to the CSMS.
CancelReservationStatusEnum
This indicates the success or failure of the canceling of a reservation by CSMS.
CertificateActionEnum
Defines whether certificate needs to be installed or updated.
CertificateSignedStatusEnum
Returns whether certificate signing has been accepted, otherwise rejected.
CertificateSigningUseEnum
Indicates the type of the signed certificate that is returned. When omitted the certificate is used for both the 15118 connection (if implemented) and the Charging Station to CSMS connection. This field is required when a typeOfCertificate was included in the <<signcertificaterequest,SignCertificateRequest>> that requested this certificate to be signed AND both the 15118 connection and the Charging Station connection are implemented.
ChangeAvailabilityStatusEnum
This indicates whether the Charging Station is able to perform the availability change.
ChargingLimitSourceEnum
Source of the charging limit.
ChargingProfileKindEnum
Charging_ Profile. Charging_ Profile_ Kind. Charging_ Profile_ Kind_ Code urn:x-oca:ocpp:uid:1:569232 Indicates the kind of schedule.
ChargingProfilePurposeEnum
Charging_ Profile. Charging_ Profile_ Purpose. Charging_ Profile_ Purpose_ Code urn:x-oca:ocpp:uid:1:569231 Specifies to purpose of the charging profiles that will be cleared, if they meet the other criteria in the request.
ChargingProfileStatusEnum
Returns whether the Charging Station has been able to process the message successfully. This does not guarantee the schedule will be followed to the letter. There might be other constraints the Charging Station may need to take into account.
ChargingRateUnitEnum
Can be used to force a power or current profile.
ChargingStateEnum
Transaction. State. Transaction_ State_ Code urn:x-oca:ocpp:uid:1:569419 Current charging state, is required when state has changed.
ClearCacheStatusEnum
Accepted if the Charging Station has executed the request, otherwise rejected.
ClearChargingProfileStatusEnum
Indicates if the Charging Station was able to execute the request.
ClearMessageStatusEnum
Returns whether the Charging Station has been able to remove the message.
ClearMonitoringStatusEnum
Result of the clear request for this monitor, identified by its Id.
ComponentCriterionEnum
ConnectorEnum
This field specifies the connector type.
ConnectorStatusEnum
This contains the current status of the Connector.
CostKindEnum
Cost. Cost_ Kind. Cost_ Kind_ Code urn:x-oca:ocpp:uid:1:569243 The kind of cost referred to in the message element amount
CustomerInformationStatusEnum
Indicates whether the request was accepted.
DataEnum
Data type of this variable.
DataTransferStatusEnum
This indicates the success or failure of the data transfer.
DeleteCertificateStatusEnum
Charging Station indicates if it can process the request.
DisplayMessageStatusEnum
This indicates whether the Charging Station is able to display the message.
EnergyTransferModeEnum
Charging_ Needs. Requested. Energy_ Transfer_ Mode_ Code urn:x-oca:ocpp:uid:1:569209 Mode of energy transfer requested by the EV.
EventNotificationEnum
Specifies the event notification type of the message.
EventTriggerEnum
Type of monitor that triggered this event, e.g. exceeding a threshold value.
FirmwareStatusEnum
This contains the progress status of the firmware installation.
GenericDeviceModelStatusEnum
This indicates whether the Charging Station is able to accept this request.
GenericStatusEnum
The Charging Station will indicate if it was able to process the request
GetCertificateIdUseEnum
GetCertificateStatusEnum
This indicates whether the charging station was able to retrieve the OCSP certificate status.
GetChargingProfileStatusEnum
This indicates whether the Charging Station is able to process this request and will send <<reportchargingprofilesrequest, ReportChargingProfilesRequest>> messages.
GetDisplayMessagesStatusEnum
Indicates if the Charging Station has Display Messages that match the request criteria in the <<getdisplaymessagesrequest,GetDisplayMessagesRequest>>
GetInstalledCertificateStatusEnum
Charging Station indicates if it can process the request.
GetVariableStatusEnum
Result status of getting the variable.
HashAlgorithmEnum
Used algorithms for the hashes provided.
IdTokenEnum
Enumeration of possible idToken types.
InstallCertificateStatusEnum
Charging Station indicates if installation was successful.
InstallCertificateUseEnum
Indicates the certificate type that is sent.
Iso15118EVCertificateStatusEnum
Indicates whether the message was processed properly.
LocationEnum
Sampled_ Value. Location. Location_ Code urn:x-oca:ocpp:uid:1:569265 Indicates where the measured value has been sampled. Default = “Outlet”
LogEnum
This contains the type of log file that the Charging Station should send.
LogStatusEnum
This field indicates whether the Charging Station was able to accept the request.
MeasurandEnum
Sampled_ Value. Measurand. Measurand_ Code urn:x-oca:ocpp:uid:1:569263 Type of measurement. Default = “Energy.Active.Import.Register”
MessageFormatEnum
Message_ Content. Format. Message_ Format_ Code urn:x-enexis:ecdm:uid:1:570848 Format of the message.
MessagePriorityEnum
If provided the Charging Station shall return Display Messages with the given priority only.
MessageStateEnum
If provided the Charging Station shall return Display Messages with the given state only.
MessageTriggerEnum
Type of message to be triggered.
MonitorEnum
The type of this monitor, e.g. a threshold, delta or periodic monitor.
MonitoringBaseEnum
Specify which monitoring base will be set
MonitoringCriterionEnum
MutabilityEnum
Defines the mutability of this attribute. Default is ReadWrite when omitted.
NotifyEVChargingNeedsStatusEnum
Returns whether the CSMS has been able to process the message successfully. It does not imply that the evChargingNeeds can be met with the current charging profile.
OCPPInterfaceEnum
Applicable Network Interface.
OCPPTransportEnum
Communication_ Function. OCPP_ Transport. OCPP_ Transport_ Code urn:x-oca:ocpp:uid:1:569356 Defines the transport protocol (e.g. SOAP or JSON). Note: SOAP is not supported in OCPP 2.0, but is supported by other versions of OCPP.
OCPPVersionEnum
Communication_ Function. OCPP_ Version. OCPP_ Version_ Code urn:x-oca:ocpp:uid:1:569355 Defines the OCPP version used for this communication function.
OperationalStatusEnum
This contains the type of availability change that the Charging Station should perform.
PhaseEnum
Sampled_ Value. Phase. Phase_ Code urn:x-oca:ocpp:uid:1:569264 Indicates how the measured value is to be interpreted. For instance between L1 and neutral (L1-N) Please note that not all values of phase are applicable to all Measurands. When phase is absent, the measured value is interpreted as an overall value.
PublishFirmwareStatusEnum
This contains the progress status of the publishfirmware installation.
ReadingContextEnum
Sampled_ Value. Context. Reading_ Context_ Code urn:x-oca:ocpp:uid:1:569261 Type of detail value: start, end or sample. Default = “Sample.Periodic”
ReasonEnum
Transaction. Stopped_ Reason. EOT_ Reason_ Code urn:x-oca:ocpp:uid:1:569413 This contains the reason why the transaction was stopped. MAY only be omitted when Reason is “Local”.
RecurrencyKindEnum
Charging_ Profile. Recurrency_ Kind. Recurrency_ Kind_ Code urn:x-oca:ocpp:uid:1:569233 Indicates the start point of a recurrence.
RegistrationStatusEnum
This contains whether the Charging Station has been registered within the CSMS.
ReportBaseEnum
This field specifies the report base.
RequestStartStopStatusEnum
Status indicating whether the Charging Station accepts the request to start a transaction.
ReservationUpdateStatusEnum
The updated reservation status.
ReserveNowStatusEnum
This indicates the success or failure of the reservation.
ResetEnum
This contains the type of reset that the Charging Station or EVSE should perform.
ResetStatusEnum
This indicates whether the Charging Station is able to perform the reset.
SendLocalListStatusEnum
This indicates whether the Charging Station has successfully received and applied the update of the Local Authorization List.
SetMonitoringStatusEnum
Status is OK if a value could be returned. Otherwise this will indicate the reason why a value could not be returned.
SetNetworkProfileStatusEnum
Result of operation.
SetVariableStatusEnum
Result status of setting the variable.
TransactionEventEnum
This contains the type of this event. The first TransactionEvent of a transaction SHALL contain: “Started” The last TransactionEvent of a transaction SHALL contain: “Ended” All others SHALL contain: “Updated”
TriggerMessageStatusEnum
Indicates whether the Charging Station will send the requested notification or not.
TriggerReasonEnum
Reason the Charging Station sends this message to the CSMS
UnlockStatusEnum
This indicates whether the Charging Station has unlocked the connector.
UnpublishFirmwareStatusEnum
Indicates whether the Local Controller succeeded in unpublishing the firmware.
UpdateEnum
This contains the type of update (full or differential) of this request.
UpdateFirmwareStatusEnum
This field indicates whether the Charging Station was able to accept the request.
UploadLogStatusEnum
This contains the status of the log upload.
VPNEnum
VPN. Type. VPN_ Code urn:x-oca:ocpp:uid:1:569277 Type of VPN