Component

Struct Component 

pub struct Component {
    pub custom_data: Option<CustomData>,
    pub evse: Option<EVSE>,
    pub instance: Option<String<50usize>>,
    pub name: String<50usize>,
}
A physical or logical component

Fields

custom_data: Option<CustomData>evse: Option<EVSE>instance: Option<String<50usize>>

Name of instance in case the component exists as multiple instances. Case Insensitive. strongly advised to use Camel Case.

name: String<50usize>

Name of the component. Name should be taken from the list of standardized component names whenever possible. Case Insensitive. strongly advised to use Camel Case.