pub struct CompositeSchedule<CustomDataType = NoCustomData> {
pub charging_rate_unit: ChargingRateUnitEnum,
pub charging_schedule_period: Vec<ChargingSchedulePeriod<CustomDataType>>,
pub custom_data: Option<CustomDataType>,
pub duration: i64,
pub evse_id: i64,
pub schedule_start: OcppTimestamp,
}Expand description
Composite_ Schedule urn:x-oca:ocpp:uid:2:233362
Fields
charging_rate_unit: ChargingRateUnitEnumcharging_schedule_period: Vec<ChargingSchedulePeriod<CustomDataType>>custom_data: Option<CustomDataType>duration: i64Duration of the schedule in seconds.
evse_id: i64The ID of the EVSE for which the schedule is requested. When evseid=0, the Charging Station calculated the expected consumption for the grid connection.
schedule_start: OcppTimestampComposite_ Schedule. Start. Date_ Time urn:x-oca:ocpp:uid:1:569456 Date and time at which the schedule becomes active. All time measurements within the schedule are relative to this timestamp.