pub struct Firmware<CustomDataType = NoCustomData> {
pub custom_data: Option<CustomDataType>,
pub install_date_time: Option<OcppTimestamp>,
pub location: String<512usize>,
pub retrieve_date_time: OcppTimestamp,
pub signature: Option<String>,
pub signing_certificate: Option<String>,
}Expand description
Firmware urn:x-enexis:ecdm:uid:2:233291 Represents a copy of the firmware that can be loaded/updated on the Charging Station.
Fields
custom_data: Option<CustomDataType>install_date_time: Option<OcppTimestamp>Firmware. Install. Date_ Time urn:x-enexis:ecdm:uid:1:569462 Date and time at which the firmware shall be installed.
location: String<512usize>Firmware. Location. URI urn:x-enexis:ecdm:uid:1:569460 URI defining the origin of the firmware.
retrieve_date_time: OcppTimestampFirmware. Retrieve. Date_ Time urn:x-enexis:ecdm:uid:1:569461 Date and time at which the firmware shall be retrieved.
signature: Option<String>Firmware. Signature. Signature urn:x-enexis:ecdm:uid:1:569464 Base64 encoded firmware signature.
signing_certificate: Option<String>Certificate with which the firmware was signed. PEM encoded X.509 certificate.