pub struct GetVariableResult<CustomDataType = NoCustomData> {
pub attribute_status: GetVariableStatusEnum,
pub attribute_status_info: Option<StatusInfo<CustomDataType>>,
pub attribute_type: Option<AttributeEnum>,
pub attribute_value: Option<String>,
pub component: Component<CustomDataType>,
pub custom_data: Option<CustomDataType>,
pub variable: Variable<CustomDataType>,
}Expand description
Class to hold results of GetVariables request.
Fields
attribute_status: GetVariableStatusEnumattribute_status_info: Option<StatusInfo<CustomDataType>>attribute_type: Option<AttributeEnum>attribute_value: Option<String>Value of requested attribute type of component-variable. This field can only be empty when the given status is NOT accepted.
The Configuration Variable <<configkey-reporting-value-size,ReportingValueSize>> can be used to limit GetVariableResult.attributeValue, VariableAttribute.value and EventData.actualValue. The max size of these values will always remain equal.
component: Component<CustomDataType>custom_data: Option<CustomDataType>variable: Variable<CustomDataType>Trait Implementations
Sourceimpl<CustomDataType: Clone> Clone for GetVariableResult<CustomDataType>
impl<CustomDataType: Clone> Clone for GetVariableResult<CustomDataType>
Sourcefn clone(&self) -> GetVariableResult<CustomDataType>
fn clone(&self) -> GetVariableResult<CustomDataType>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<CustomDataType: Debug> Debug for GetVariableResult<CustomDataType>
impl<CustomDataType: Debug> Debug for GetVariableResult<CustomDataType>
Sourceimpl<'de, CustomDataType> Deserialize<'de> for GetVariableResult<CustomDataType>where
CustomDataType: Deserialize<'de>,
impl<'de, CustomDataType> Deserialize<'de> for GetVariableResult<CustomDataType>where
CustomDataType: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<CustomDataType: Eq> Eq for GetVariableResult<CustomDataType>
Sourceimpl<CustomDataType: PartialEq> PartialEq for GetVariableResult<CustomDataType>
impl<CustomDataType: PartialEq> PartialEq for GetVariableResult<CustomDataType>
Sourceimpl<CustomDataType> Serialize for GetVariableResult<CustomDataType>where
CustomDataType: Serialize,
impl<CustomDataType> Serialize for GetVariableResult<CustomDataType>where
CustomDataType: Serialize,
impl<CustomDataType: PartialEq> StructuralPartialEq for GetVariableResult<CustomDataType>
Sourceimpl<CustomDataType> Validate for GetVariableResult<CustomDataType>
Available on crate features alloc and validate only.
impl<CustomDataType> Validate for GetVariableResult<CustomDataType>
Available on crate features
alloc and validate only.Auto Trait Implementations
impl<CustomDataType> Freeze for GetVariableResult<CustomDataType>where
CustomDataType: Freeze,
impl<CustomDataType> RefUnwindSafe for GetVariableResult<CustomDataType>where
CustomDataType: RefUnwindSafe,
impl<CustomDataType> Send for GetVariableResult<CustomDataType>where
CustomDataType: Send,
impl<CustomDataType> Sync for GetVariableResult<CustomDataType>where
CustomDataType: Sync,
impl<CustomDataType> Unpin for GetVariableResult<CustomDataType>where
CustomDataType: Unpin,
impl<CustomDataType> UnsafeUnpin for GetVariableResult<CustomDataType>where
CustomDataType: UnsafeUnpin,
impl<CustomDataType> UnwindSafe for GetVariableResult<CustomDataType>where
CustomDataType: UnwindSafe,