pub struct MessageInfo<CustomDataType = NoCustomData> {
pub custom_data: Option<CustomDataType>,
pub display: Option<Component<CustomDataType>>,
pub end_date_time: Option<OcppTimestamp>,
pub id: i64,
pub message: MessageContent<CustomDataType>,
pub priority: MessagePriorityEnum,
pub start_date_time: Option<OcppTimestamp>,
pub state: Option<MessageStateEnum>,
pub transaction_id: Option<String<36usize>>,
}Expand description
Message_ Info urn:x-enexis:ecdm:uid:2:233264 Contains message details, for a message to be displayed on a Charging Station.
Fields
custom_data: Option<CustomDataType>display: Option<Component<CustomDataType>>end_date_time: Option<OcppTimestamp>Message_ Info. End. Date_ Time urn:x-enexis:ecdm:uid:1:569257 Until what date-time should this message be shown, after this date/time this message SHALL be removed.
id: i64Identified_ Object. MRID. Numeric_ Identifier urn:x-enexis:ecdm:uid:1:569198 Master resource identifier, unique within an exchange context. It is defined within the OCPP context as a positive Integer value (greater or equal to zero).
message: MessageContent<CustomDataType>priority: MessagePriorityEnumstart_date_time: Option<OcppTimestamp>Message_ Info. Start. Date_ Time urn:x-enexis:ecdm:uid:1:569256 From what date-time should this message be shown. If omitted: directly.
state: Option<MessageStateEnum>transaction_id: Option<String<36usize>>During which transaction shall this message be shown. Message SHALL be removed by the Charging Station after transaction has ended.