pub struct NetworkConnectionProfile<CustomDataType = NoCustomData> {
pub apn: Option<APN<CustomDataType>>,
pub custom_data: Option<CustomDataType>,
pub message_timeout: i64,
pub ocpp_csms_url: String<512usize>,
pub ocpp_interface: OCPPInterfaceEnum,
pub ocpp_transport: OCPPTransportEnum,
pub ocpp_version: OCPPVersionEnum,
pub security_profile: i64,
pub vpn: Option<VPN<CustomDataType>>,
}Expand description
Communication_ Function urn:x-oca:ocpp:uid:2:233304 The NetworkConnectionProfile defines the functional and technical parameters of a communication link.
Fields
apn: Option<APN<CustomDataType>>custom_data: Option<CustomDataType>message_timeout: i64Duration in seconds before a message send by the Charging Station via this network connection times-out. The best setting depends on the underlying network and response times of the CSMS. If you are looking for a some guideline: use 30 seconds as a starting point.
ocpp_csms_url: String<512usize>Communication_ Function. OCPP_ Central_ System_ URL. URI urn:x-oca:ocpp:uid:1:569357 URL of the CSMS(s) that this Charging Station communicates with.
ocpp_interface: OCPPInterfaceEnumocpp_transport: OCPPTransportEnumocpp_version: OCPPVersionEnumsecurity_profile: i64This field specifies the security profile used when connecting to the CSMS with this NetworkConnectionProfile.
vpn: Option<VPN<CustomDataType>>Trait Implementations
Sourceimpl<CustomDataType: Clone> Clone for NetworkConnectionProfile<CustomDataType>
impl<CustomDataType: Clone> Clone for NetworkConnectionProfile<CustomDataType>
Sourcefn clone(&self) -> NetworkConnectionProfile<CustomDataType>
fn clone(&self) -> NetworkConnectionProfile<CustomDataType>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<CustomDataType: Debug> Debug for NetworkConnectionProfile<CustomDataType>
impl<CustomDataType: Debug> Debug for NetworkConnectionProfile<CustomDataType>
Sourceimpl<'de, CustomDataType> Deserialize<'de> for NetworkConnectionProfile<CustomDataType>where
CustomDataType: Deserialize<'de>,
impl<'de, CustomDataType> Deserialize<'de> for NetworkConnectionProfile<CustomDataType>where
CustomDataType: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<CustomDataType: Eq> Eq for NetworkConnectionProfile<CustomDataType>
Sourceimpl<CustomDataType: PartialEq> PartialEq for NetworkConnectionProfile<CustomDataType>
impl<CustomDataType: PartialEq> PartialEq for NetworkConnectionProfile<CustomDataType>
Sourceimpl<CustomDataType> Serialize for NetworkConnectionProfile<CustomDataType>where
CustomDataType: Serialize,
impl<CustomDataType> Serialize for NetworkConnectionProfile<CustomDataType>where
CustomDataType: Serialize,
impl<CustomDataType: PartialEq> StructuralPartialEq for NetworkConnectionProfile<CustomDataType>