pub struct SalesTariff<CustomDataType = NoCustomData> {
pub custom_data: Option<CustomDataType>,
pub id: i64,
pub num_e_price_levels: Option<i64>,
pub sales_tariff_description: Option<String<32usize>>,
pub sales_tariff_entry: Vec<SalesTariffEntry<CustomDataType>>,
}Expand description
Sales_ Tariff urn:x-oca:ocpp:uid:2:233272 NOTE: This dataType is based on dataTypes from <<ref-ISOIEC15118-2,ISO 15118-2>>.
Fields
custom_data: Option<CustomDataType>id: i64Identified_ Object. MRID. Numeric_ Identifier urn:x-enexis:ecdm:uid:1:569198 SalesTariff identifier used to identify one sales tariff. An SAID remains a unique identifier for one schedule throughout a charging session.
num_e_price_levels: Option<i64>Sales_ Tariff. Num_ E_ Price_ Levels. Counter urn:x-oca:ocpp:uid:1:569284 Defines the overall number of distinct price levels used across all provided SalesTariff elements.
sales_tariff_description: Option<String<32usize>>Sales_ Tariff. Sales. Tariff_ Description urn:x-oca:ocpp:uid:1:569283 A human readable title/short description of the sales tariff e.g. for HMI display purposes.
sales_tariff_entry: Vec<SalesTariffEntry<CustomDataType>>Trait Implementations
Sourceimpl<CustomDataType: Clone> Clone for SalesTariff<CustomDataType>
impl<CustomDataType: Clone> Clone for SalesTariff<CustomDataType>
Sourcefn clone(&self) -> SalesTariff<CustomDataType>
fn clone(&self) -> SalesTariff<CustomDataType>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<CustomDataType: Debug> Debug for SalesTariff<CustomDataType>
impl<CustomDataType: Debug> Debug for SalesTariff<CustomDataType>
Sourceimpl<'de, CustomDataType> Deserialize<'de> for SalesTariff<CustomDataType>where
CustomDataType: Deserialize<'de>,
impl<'de, CustomDataType> Deserialize<'de> for SalesTariff<CustomDataType>where
CustomDataType: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<CustomDataType: PartialEq> PartialEq for SalesTariff<CustomDataType>
impl<CustomDataType: PartialEq> PartialEq for SalesTariff<CustomDataType>
Sourceimpl<CustomDataType> Serialize for SalesTariff<CustomDataType>where
CustomDataType: Serialize,
impl<CustomDataType> Serialize for SalesTariff<CustomDataType>where
CustomDataType: Serialize,
impl<CustomDataType: PartialEq> StructuralPartialEq for SalesTariff<CustomDataType>
Sourceimpl<CustomDataType> Validate for SalesTariff<CustomDataType>
Available on crate features alloc and validate only.
impl<CustomDataType> Validate for SalesTariff<CustomDataType>
Available on crate features
alloc and validate only.Auto Trait Implementations
impl<CustomDataType> Freeze for SalesTariff<CustomDataType>where
CustomDataType: Freeze,
impl<CustomDataType> RefUnwindSafe for SalesTariff<CustomDataType>where
CustomDataType: RefUnwindSafe,
impl<CustomDataType> Send for SalesTariff<CustomDataType>where
CustomDataType: Send,
impl<CustomDataType> Sync for SalesTariff<CustomDataType>where
CustomDataType: Sync,
impl<CustomDataType> Unpin for SalesTariff<CustomDataType>where
CustomDataType: Unpin,
impl<CustomDataType> UnsafeUnpin for SalesTariff<CustomDataType>where
CustomDataType: UnsafeUnpin,
impl<CustomDataType> UnwindSafe for SalesTariff<CustomDataType>where
CustomDataType: UnwindSafe,