pub struct SignedMeterValue<CustomDataType = NoCustomData> {
pub custom_data: Option<CustomDataType>,
pub encoding_method: String<50usize>,
pub public_key: String,
pub signed_meter_data: String,
pub signing_method: String<50usize>,
}Expand description
Represent a signed version of the meter value.
Fields
custom_data: Option<CustomDataType>encoding_method: String<50usize>Method used to encode the meter values before applying the digital signature algorithm.
public_key: StringBase64 encoded, sending depends on configuration variable PublicKeyWithSignedMeterValue.
signed_meter_data: StringBase64 encoded, contains the signed data which might contain more then just the meter value. It can contain information like timestamps, reference to a customer etc.
signing_method: String<50usize>Method used to create the digital signature.