Transaction

Struct Transaction 

pub struct Transaction<CustomDataType = NoCustomData> {
    pub charging_state: Option<ChargingStateEnum>,
    pub custom_data: Option<CustomDataType>,
    pub remote_start_id: Option<i64>,
    pub stopped_reason: Option<ReasonEnum>,
    pub time_spent_charging: Option<i64>,
    pub transaction_id: String<36usize>,
}
Transaction urn:x-oca:ocpp:uid:2:233318

Fields

charging_state: Option<ChargingStateEnum>custom_data: Option<CustomDataType>remote_start_id: Option<i64>

The ID given to remote start request (<<requeststarttransactionrequest, RequestStartTransactionRequest>>. This enables to CSMS to match the started transaction to the given start request.

stopped_reason: Option<ReasonEnum>time_spent_charging: Option<i64>

Transaction. Time_ Spent_ Charging. Elapsed_ Time urn:x-oca:ocpp:uid:1:569415 Contains the total time that energy flowed from EVSE to EV during the transaction (in seconds). Note that timeSpentCharging is smaller or equal to the duration of the transaction.

transaction_id: String<36usize>

This contains the Id of the transaction.