VariableCharacteristics

Struct VariableCharacteristics 

pub struct VariableCharacteristics {
    pub custom_data: Option<CustomData>,
    pub data_type: DataEnum,
    pub max_limit: Option<f64>,
    pub min_limit: Option<f64>,
    pub supports_monitoring: bool,
    pub unit: Option<String<16usize>>,
    pub values_list: Option<String<1000usize>>,
}
Fixed read-only parameters of a variable.

Fields

custom_data: Option<CustomData>data_type: DataEnummax_limit: Option<f64>

Maximum possible value of this variable. When the datatype of this Variable is String, OptionList, SequenceList or MemberList, this field defines the maximum length of the (CSV) string.

min_limit: Option<f64>

Minimum possible value of this variable.

supports_monitoring: bool

Flag indicating if this variable supports monitoring.

unit: Option<String<16usize>>

Unit of the variable. When the transmitted value has a unit, this field SHALL be included.

values_list: Option<String<1000usize>>

Allowed values when variable is Option/Member/SequenceList.

  • OptionList: The (Actual) Variable value must be a single value from the reported (CSV) enumeration list.

  • MemberList: The (Actual) Variable value may be an (unordered) (sub-)set of the reported (CSV) valid values list.

  • SequenceList: The (Actual) Variable value may be an ordered (priority, etc) (sub-)set of the reported (CSV) valid values.

This is a comma separated list.

The Configuration Variable <<configkey-configuration-value-size,ConfigurationValueSize>> can be used to limit SetVariableData.attributeValue and VariableCharacteristics.valueList. The max size of these values will always remain equal.