CustomerInformationRequest

Struct CustomerInformationRequest 

pub struct CustomerInformationRequest<const ID_TOKEN_ADDITIONAL_INFO_CAP: usize = 16> {
    pub clear: bool,
    pub custom_data: Option<CustomData>,
    pub customer_certificate: Option<CertificateHashData>,
    pub customer_identifier: Option<String<64usize>>,
    pub id_token: Option<IdToken<ID_TOKEN_ADDITIONAL_INFO_CAP>>,
    pub report: bool,
    pub request_id: i64,
}

Fields

clear: bool

Flag indicating whether the Charging Station should clear all information about the customer referred to.

custom_data: Option<CustomData>customer_certificate: Option<CertificateHashData>customer_identifier: Option<String<64usize>>

A (e.g. vendor specific) identifier of the customer this request refers to. This field contains a custom identifier other than IdToken and Certificate. One of the possible identifiers (customerIdentifier, customerIdToken or customerCertificate) should be in the request message.

id_token: Option<IdToken<ID_TOKEN_ADDITIONAL_INFO_CAP>>report: bool

Flag indicating whether the Charging Station should return NotifyCustomerInformationRequest messages containing information about the customer referred to.

request_id: i64

The Id of the request.