GetLogRequest

Struct GetLogRequest 

pub struct GetLogRequest<const LOG_PARAMETERS_LATEST_TIMESTAMP_CAP: usize = 1024, const LOG_PARAMETERS_OLDEST_TIMESTAMP_CAP: usize = 1024> {
    pub custom_data: Option<CustomData>,
    pub log: LogParameters<LOG_PARAMETERS_LATEST_TIMESTAMP_CAP, LOG_PARAMETERS_OLDEST_TIMESTAMP_CAP>,
    pub log_type: LogEnum,
    pub request_id: i64,
    pub retries: Option<i64>,
    pub retry_interval: Option<i64>,
}

Fields

custom_data: Option<CustomData>log: LogParameters<LOG_PARAMETERS_LATEST_TIMESTAMP_CAP, LOG_PARAMETERS_OLDEST_TIMESTAMP_CAP>log_type: LogEnumrequest_id: i64

The Id of this request

retries: Option<i64>

This specifies how many times the Charging Station must try to upload the log before giving up. If this field is not present, it is left to Charging Station to decide how many times it wants to retry.

retry_interval: Option<i64>

The interval in seconds after which a retry may be attempted. If this field is not present, it is left to Charging Station to decide how long to wait between attempts.