pub struct GetLogResponse {
pub custom_data: Option<CustomData>,
pub filename: Option<String<255usize>>,
pub status: LogStatusEnum,
pub status_info: Option<StatusInfo>,
}Fields
custom_data: Option<CustomData>filename: Option<String<255usize>>This contains the name of the log file that will be uploaded. This field is not present when no logging information is available.
status: LogStatusEnumstatus_info: Option<StatusInfo>Trait Implementations
Sourceimpl Clone for GetLogResponse
impl Clone for GetLogResponse
Sourcefn clone(&self) -> GetLogResponse
fn clone(&self) -> GetLogResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetLogResponse
impl Debug for GetLogResponse
impl Eq for GetLogResponse
Sourceimpl PartialEq for GetLogResponse
impl PartialEq for GetLogResponse
impl StructuralPartialEq for GetLogResponse