pub struct NotifyReportRequest<const NOTIFY_REPORT_REQUEST_GENERATED_AT_CAP: usize = 1024, const NOTIFY_REPORT_REQUEST_REPORT_DATA_CAP: usize = 16> {
pub custom_data: Option<CustomData>,
pub generated_at: String<NOTIFY_REPORT_REQUEST_GENERATED_AT_CAP>,
pub report_data: Option<Vec<ReportData, NOTIFY_REPORT_REQUEST_REPORT_DATA_CAP>>,
pub request_id: i64,
pub seq_no: i64,
pub tbc: Option<bool>,
}Fields
custom_data: Option<CustomData>generated_at: String<NOTIFY_REPORT_REQUEST_GENERATED_AT_CAP>Timestamp of the moment this message was generated at the Charging Station.
report_data: Option<Vec<ReportData, NOTIFY_REPORT_REQUEST_REPORT_DATA_CAP>>request_id: i64The id of the GetReportRequest or GetBaseReportRequest that requested this report
seq_no: i64Sequence number of this message. First message starts at 0.
tbc: Option<bool>“to be continued” indicator. Indicates whether another part of the report follows in an upcoming notifyReportRequest message. Default value when omitted is false.