pub struct UnlockConnectorRequest {
pub connector_id: i64,
pub custom_data: Option<CustomData>,
pub evse_id: i64,
}Fields
connector_id: i64This contains the identifier of the connector that needs to be unlocked.
custom_data: Option<CustomData>evse_id: i64This contains the identifier of the EVSE for which a connector needs to be unlocked.