Module common

Module common 

Structs

ACChargingParameters
EV AC charging parameters for ISO 15118-2
APN
Collection of configuration data needed to make a data-connection over a cellular network.
AbsolutePriceSchedule
The AbsolutePriceScheduleType is modeled after the same type that is defined in ISO 15118-20, such that if it is supplied by an EMSP as a signed EXI message, the conversion from EXI to JSON (in OCPP) and back to EXI (for ISO 15118-20) does not change the digest and therefore does not invalidate the signature.
AdditionalInfo
Contains a case insensitive identifier to use for the authorization and the type of authorization to support multiple forms of identifiers.
AdditionalSelectedServices
Part of ISO 15118-20 price schedule.
Address
(2.1) A generic address format.
AuthorizationData
Contains the identifier to use for authorization.
BatteryData
CertificateHashData
CertificateHashDataChain
CertificateStatus
Revocation status of certificate
CertificateStatusRequestInfo
Data necessary to request the revocation status of a certificate.
ChargingLimit
ChargingNeeds
ChargingPeriod
A ChargingPeriodType consists of a start time, and a list of possible values that influence this period, for example: amount of energy charged this period, maximum current during this period etc.
ChargingProfile
A ChargingProfile consists of 1 to 3 ChargingSchedules with a list of ChargingSchedulePeriods, describing the amount of power or current that can be delivered per time interval.
ChargingProfileCriterion
A ChargingProfileCriterionType is a filter for charging profiles to be selected by a GetChargingProfilesRequest.
ChargingSchedule
Charging schedule structure defines a list of charging periods, as used in: NotifyEVChargingScheduleRequest and ChargingProfileType. When used in a NotifyEVChargingScheduleRequest only duration and chargingSchedulePeriod are relevant and chargingRateUnit must be ‘W’. + An ISO 15118-20 session may provide either an absolutePriceSchedule or a priceLevelSchedule. An ISO 15118-2 session can only provide a_salesTariff_ element. The field digestValue is used when price schedule or sales tariff are signed.
ChargingSchedulePeriod
Charging schedule period structure defines a time period in a charging schedule. It is used in: CompositeScheduleType and in ChargingScheduleType. When used in a NotifyEVChargingScheduleRequest only startPeriod, limit, limit_L2, limit_L3 are relevant.
ChargingScheduleUpdate
Updates to a ChargingSchedulePeriodType for dynamic charging profiles.
ChargingStation
The physical system where an Electrical Vehicle (EV) can be charged.
ClearChargingProfile
A ClearChargingProfileType is a filter for charging profiles to be cleared by ClearChargingProfileRequest.
ClearMonitoringResult
ClearTariffsResult
Component
A physical or logical component
ComponentVariable
Class to report components, variables and variable attributes and characteristics.
CompositeSchedule
ConstantStreamData
ConsumptionCost
Cost
CostDetails
CostDetailsType contains the cost as calculated by Charging Station based on provided TariffType.
CostDimension
Volume consumed of cost dimension.
CustomData
This class does not get ‘AdditionalProperties = false’ in the schema generation, so it can be extended with arbitrary JSON properties to allow adding custom data.
DCChargingParameters
EV DC charging parameters for ISO 15118-2
DERChargingParameters
(2.1) DERChargingParametersType is used in ChargingNeedsType during an ISO 15118-20 session for AC_BPT_DER to report the inverter settings related to DER control that were agreed between EVSE and EV.
DERCurve
DERCurveGet
DERCurvePoints
EVAbsolutePriceSchedule
(2.1) Price schedule of EV energy offer.
EVAbsolutePriceScheduleEntry
(2.1) An entry in price schedule over time for which EV is willing to discharge.
EVEnergyOffer
(2.1) A schedule of the energy amount over time that EV is willing to discharge. A negative value indicates the willingness to discharge under specific conditions, a positive value indicates that the EV currently is not able to offer energy to discharge.
EVPowerSchedule
(2.1) Schedule of EV energy offer.
EVPowerScheduleEntry
(2.1) An entry in schedule of the energy amount over time that EV is willing to discharge. A negative value indicates the willingness to discharge under specific conditions, a positive value indicates that the EV currently is not able to offer energy to discharge.
EVPriceRule
(2.1) An entry in price schedule over time for which EV is willing to discharge.
EVSE
Electric Vehicle Supply Equipment
EnterService
EnterServiceGet
EventData
Class to report an event notification for a component-variable.
Firmware
Represents a copy of the firmware that can be loaded/updated on the Charging Station.
FixedPF
FixedPFGet
FixedVar
FixedVarGet
FreqDroop
FreqDroopGet
GetVariableData
Class to hold parameters for GetVariables request.
GetVariableResult
Class to hold results of GetVariables request.
Gradient
GradientGet
Hysteresis
IdToken
Contains a case insensitive identifier to use for the authorization and the type of authorization to support multiple forms of identifiers.
IdTokenInfo
Contains status information about an identifier. It is advised to not stop charging for a token that expires during charging, as ExpiryDate is only used for caching purposes. If ExpiryDate is not given, the status has no end date.
LimitAtSoC
LimitMaxDischarge
LimitMaxDischargeGet
LogParameters
Generic class for the configuration of logging entries.
MessageContent
Contains message details, for a message to be displayed on a Charging Station.
MessageInfo
Contains message details, for a message to be displayed on a Charging Station.
MeterValue
Collection of one or more sampled values in MeterValuesRequest and TransactionEvent. All sampled values in a MeterValue are sampled at the same point in time.
Modem
Defines parameters required for initiating and maintaining wireless communication with other devices.
MonitoringData
Class to hold parameters of SetVariableMonitoring request.
NetworkConnectionProfile
The NetworkConnectionProfile defines the functional and technical parameters of a communication link.
OCSPRequestData
Information about a certificate for an OCSP check.
OverstayRule
Part of ISO 15118-20 price schedule.
OverstayRuleList
Part of ISO 15118-20 price schedule.
PeriodicEventStreamParams
Price
Price with and without tax. At least one of exclTax, inclTax must be present.
PriceLevelSchedule
The PriceLevelScheduleType is modeled after the same type that is defined in ISO 15118-20, such that if it is supplied by an EMSP as a signed EXI message, the conversion from EXI to JSON (in OCPP) and back to EXI (for ISO 15118-20) does not change the digest and therefore does not invalidate the signature.
PriceLevelScheduleEntry
Part of ISO 15118-20 price schedule.
PriceRule
Part of ISO 15118-20 price schedule.
PriceRuleStack
Part of ISO 15118-20 price schedule.
RationalNumber
Part of ISO 15118-20 price schedule.
ReactivePowerParams
RelativeTimeInterval
ReportData
Class to report components, variables and variable attributes and characteristics.
SalesTariff
A SalesTariff provided by a Mobility Operator (EMSP) . NOTE: This dataType is based on dataTypes from <<ref-ISOIEC15118-2,ISO 15118-2>>.
SalesTariffEntry
SampledValue
Single sampled value in MeterValues. Each value can be accompanied by optional fields.
SetMonitoringData
Class to hold parameters of SetVariableMonitoring request.
SetMonitoringResult
Class to hold result of SetVariableMonitoring request.
SetVariableData
SetVariableResult
SignedMeterValue
Represent a signed version of the meter value.
StatusInfo
Element providing more information about the status.
StreamDataElement
Tariff
A tariff is described by fields with prices for: energy, charging time, idle time, fixed fee, reservation time, reservation fixed fee. + Each of these fields may have (optional) conditions that specify when a price is applicable. + The description contains a human-readable explanation of the tariff to be shown to the user. + The other fields are parameters that define the tariff. These are used by the charging station to calculate the price.
TariffAssignment
Shows assignment of tariffs to EVSE or IdToken.
TariffConditions
These conditions describe if and when a TariffEnergyType or TariffTimeType applies during a transaction.
TariffConditionsFixed
These conditions describe if a FixedPrice applies at start of the transaction.
TariffEnergy
Price elements and tax for energy
TariffEnergyPrice
Tariff with optional conditions for an energy price.
TariffFixed
TariffFixedPrice
Tariff with optional conditions for a fixed price.
TariffTime
Price elements and tax for time
TariffTimePrice
Tariff with optional conditions for a time duration price.
TaxRate
Tax percentage
TaxRule
Part of ISO 15118-20 price schedule.
TotalCost
This contains the cost calculated during a transaction. It is used both for running cost and final cost of the transaction.
TotalPrice
Total cost with and without tax. Contains the total of energy, charging time, idle time, fixed and reservation costs including and/or excluding tax.
TotalUsage
This contains the calculated usage of energy, charging time and idle time during a transaction.
Transaction
TransactionLimit
Cost, energy, time or SoC limit for a transaction.
UnitOfMeasure
Represents a UnitOfMeasure with a multiplier
V2XChargingParameters
Charging parameters for ISO 15118-20, also supporting V2X charging/discharging.+ All values are greater or equal to zero, with the exception of EVMinEnergyRequest, EVMaxEnergyRequest, EVTargetEnergyRequest, EVMinV2XEnergyRequest and EVMaxV2XEnergyRequest.
V2XFreqWattPoint
(2.1) A point of a frequency-watt curve.
V2XSignalWattPoint
(2.1) A point of a signal-watt curve.
VPN
VPN Configuration settings
Variable
Reference key to a component-variable.
VariableAttribute
Attribute data of a variable.
VariableCharacteristics
Fixed read-only parameters of a variable.
VariableMonitoring
A monitoring setting for a variable.
VoltageParams

Enums

APNAuthenticationEnum
Authentication method.
AttributeEnum
Attribute type for which value is requested. When absent, default Actual is assumed.
AuthorizationStatusEnum
Current status of the ID Token.
AuthorizeCertificateStatusEnum
Certificate status information.
BatterySwapEventEnum
Battery in/out
BootReasonEnum
This contains the reason for sending this message to the CSMS.
CancelReservationStatusEnum
This indicates the success or failure of the canceling of a reservation by CSMS.
CertificateActionEnum
Defines whether certificate needs to be installed or updated.
CertificateSignedStatusEnum
Returns whether certificate signing has been accepted, otherwise rejected.
CertificateSigningUseEnum
Indicates the type of the signed certificate that is returned. When omitted the certificate is used for both the 15118 connection (if implemented) and the Charging Station to CSMS connection. This field is required when a typeOfCertificate was included in the <<signcertificaterequest,SignCertificateRequest>> that requested this certificate to be signed AND both the 15118 connection and the Charging Station connection are implemented.
CertificateStatusEnum
Status of certificate: good, revoked or unknown.
CertificateStatusSourceEnum
Source of status: OCSP, CRL
ChangeAvailabilityStatusEnum
This indicates whether the Charging Station is able to perform the availability change.
ChargingProfileKindEnum
Indicates the kind of schedule.
ChargingProfilePurposeEnum
Specifies to purpose of the charging profiles that will be cleared, if they meet the other criteria in the request.
ChargingProfileStatusEnum
Result of request.
ChargingRateUnitEnum
Can be used to force a power or current profile.
ChargingStateEnum
Current charging state, is required when state has changed. Omitted when there is no communication between EVSE and EV, because no cable is plugged in.
ClearCacheStatusEnum
Accepted if the Charging Station has executed the request, otherwise rejected.
ClearChargingProfileStatusEnum
Indicates if the Charging Station was able to execute the request.
ClearMessageStatusEnum
Returns whether the Charging Station has been able to remove the message.
ClearMonitoringStatusEnum
Result of the clear request for this monitor, identified by its Id.
ComponentCriterionEnum
ConnectorStatusEnum
This contains the current status of the Connector.
ControlModeEnum
(2.1) Indicates whether EV wants to operate in Dynamic or Scheduled mode. When absent, Scheduled mode is assumed for backwards compatibility. + ISO 15118-20: + ServiceSelectionReq(SelectedEnergyTransferService)
CostDimensionEnum
Type of cost dimension: energy, power, time, etc.
CostKindEnum
The kind of cost referred to in the message element amount
CustomerInformationStatusEnum
Indicates whether the request was accepted.
DERControlEnum
Name of control settings to clear. Not used when controlId is provided.
DERControlStatusEnum
Result of operation.
DERUnitEnum
Unit of the Y-axis of DER curve
DataEnum
Data type of this variable.
DataTransferStatusEnum
This indicates the success or failure of the data transfer.
DayOfWeekEnum
DeleteCertificateStatusEnum
Charging Station indicates if it can process the request.
DisplayMessageStatusEnum
This indicates whether the Charging Station is able to display the message.
EnergyTransferModeEnum
EventNotificationEnum
Specifies the event notification type of the message.
EventTriggerEnum
Type of trigger for this event, e.g. exceeding a threshold value.
EvseKindEnum
Type of EVSE (AC, DC) this tariff applies to.
FirmwareStatusEnum
This contains the progress status of the firmware installation.
GenericDeviceModelStatusEnum
This indicates whether the Charging Station is able to accept this request.
GenericStatusEnum
GetCertificateIdUseEnum
GetCertificateStatusEnum
This indicates whether the charging station was able to retrieve the OCSP certificate status.
GetChargingProfileStatusEnum
This indicates whether the Charging Station is able to process this request and will send <<reportchargingprofilesrequest, ReportChargingProfilesRequest>> messages.
GetDisplayMessagesStatusEnum
Indicates if the Charging Station has Display Messages that match the request criteria in the <<getdisplaymessagesrequest,GetDisplayMessagesRequest>>
GetInstalledCertificateStatusEnum
Charging Station indicates if it can process the request.
GetVariableStatusEnum
GridEventFaultEnum
Type of grid event that caused this
HashAlgorithmEnum
Used algorithms for the hashes provided.
InstallCertificateStatusEnum
Charging Station indicates if installation was successful.
InstallCertificateUseEnum
Indicates the certificate type that is sent.
IslandingDetectionEnum
Iso15118EVCertificateStatusEnum
Indicates whether the message was processed properly.
LocationEnum
Indicates where the measured value has been sampled. Default = “Outlet”
LogEnum
This contains the type of log file that the Charging Station should send.
LogStatusEnum
This field indicates whether the Charging Station was able to accept the request.
MeasurandEnum
Type of measurement. Default = “Energy.Active.Import.Register”
MessageFormatEnum
Format of the message.
MessagePriorityEnum
If provided the Charging Station shall return Display Messages with the given priority only.
MessageStateEnum
If provided the Charging Station shall return Display Messages with the given state only.
MessageTriggerEnum
Type of message to be triggered.
MobilityNeedsModeEnum
(2.1) Value of EVCC indicates that EV determines min/target SOC and departure time. + A value of EVCC_SECC indicates that charging station or CSMS may also update min/target SOC and departure time. + ISO 15118-20: + ServiceSelectionReq(SelectedEnergyTransferService)
MonitorEnum
The type of this monitor, e.g. a threshold, delta or periodic monitor.
MonitoringBaseEnum
Specify which monitoring base will be set
MonitoringCriterionEnum
MutabilityEnum
Defines the mutability of this attribute. Default is ReadWrite when omitted.
NotifyAllowedEnergyTransferStatusEnum
NotifyEVChargingNeedsStatusEnum
Returns whether the CSMS has been able to process the message successfully. It does not imply that the evChargingNeeds can be met with the current charging profile.
OCPPInterfaceEnum
Applicable Network Interface. Charging Station is allowed to use a different network interface to connect if the given one does not work.
OCPPTransportEnum
Defines the transport protocol (e.g. SOAP or JSON). Note: SOAP is not supported in OCPP 2.x, but is supported by earlier versions of OCPP.
OCPPVersionEnum
(2.1) This field is ignored, since the OCPP version to use is determined during the websocket handshake. The field is only kept for backwards compatibility with the OCPP 2.0.1 JSON schema.
OperationModeEnum
(2.1) Charging operation mode to use during this time interval. When absent defaults to ChargingOnly.
OperationalStatusEnum
This contains the type of availability change that the Charging Station should perform.
PaymentStatusEnum
The status of the settlement attempt.
PhaseEnum
Indicates how the measured value is to be interpreted. For instance between L1 and neutral (L1-N) Please note that not all values of phase are applicable to all Measurands. When phase is absent, the measured value is interpreted as an overall value.
PowerDuringCessationEnum
Parameter is only sent, if the EV has to feed-in power or reactive power during fault-ride through (FRT) as defined by HVMomCess curve and LVMomCess curve.
PreconditioningStatusEnum
(2.1) The current preconditioning status of the BMS in the EV. Default value is Unknown.
PriorityChargingStatusEnum
Result of the request.
PublishFirmwareStatusEnum
This contains the progress status of the publishfirmware installation.
ReadingContextEnum
Type of detail value: start, end or sample. Default = “Sample.Periodic”
ReasonEnum
The stoppedReason is the reason/event that initiated the process of stopping the transaction. It will normally be the user stopping authorization via card (Local or MasterPass) or app (Remote), but it can also be CSMS revoking authorization (DeAuthorized), or disconnecting the EV when TxStopPoint = EVConnected (EVDisconnected). Most other reasons are related to technical faults or energy limitations. + MAY only be omitted when stoppedReason is “Local”
RecurrencyKindEnum
Indicates the start point of a recurrence.
RegistrationStatusEnum
This contains whether the Charging Station has been registered within the CSMS.
ReportBaseEnum
This field specifies the report base.
RequestStartStopStatusEnum
Status indicating whether the Charging Station accepts the request to start a transaction.
ReservationUpdateStatusEnum
The updated reservation status.
ReserveNowStatusEnum
This indicates the success or failure of the reservation.
ResetEnum
This contains the type of reset that the Charging Station or EVSE should perform.
ResetStatusEnum
This indicates whether the Charging Station is able to perform the reset.
SendLocalListStatusEnum
This indicates whether the Charging Station has successfully received and applied the update of the Local Authorization List.
SetMonitoringStatusEnum
Status is OK if a value could be returned. Otherwise this will indicate the reason why a value could not be returned.
SetNetworkProfileStatusEnum
Result of operation.
SetVariableStatusEnum
Result status of setting the variable.
TariffChangeStatusEnum
Status of the operation
TariffClearStatusEnum
TariffCostEnum
Type of cost: normal or the minimum or maximum cost.
TariffGetStatusEnum
Status of operation
TariffKindEnum
Kind of tariff (driver/default)
TariffSetStatusEnum
TransactionEventEnum
This contains the type of this event. The first TransactionEvent of a transaction SHALL contain: “Started” The last TransactionEvent of a transaction SHALL contain: “Ended” All others SHALL contain: “Updated”
TriggerMessageStatusEnum
Indicates whether the Charging Station will send the requested notification or not.
TriggerReasonEnum
Reason the Charging Station sends this message to the CSMS
UnlockStatusEnum
This indicates whether the Charging Station has unlocked the connector.
UnpublishFirmwareStatusEnum
Indicates whether the Local Controller succeeded in unpublishing the firmware.
UpdateEnum
This contains the type of update (full or differential) of this request.
UpdateFirmwareStatusEnum
This field indicates whether the Charging Station was able to accept the request.
UploadLogStatusEnum
This contains the status of the log upload.
VPNEnum
Type of VPN