pub enum ChargingProfilePurposeEnum {
ChargingStationExternalConstraints,
ChargingStationMaxProfile,
TxDefaultProfile,
TxProfile,
PriorityCharging,
LocalGeneration,
}Expand description
Specifies to purpose of the charging profiles that will be cleared, if they meet the other criteria in the request.
Variants
ChargingStationExternalConstraints
ChargingStationMaxProfile
TxDefaultProfile
TxProfile
PriorityCharging
LocalGeneration