pub enum ControlModeEnum {
ScheduledControl,
DynamicControl,
}Expand description
(2.1) Indicates whether EV wants to operate in Dynamic or Scheduled mode. When absent, Scheduled mode is assumed for backwards compatibility. + ISO 15118-20: + ServiceSelectionReq(SelectedEnergyTransferService)
Variants