ReasonEnum

Enum ReasonEnum 

pub enum ReasonEnum {
Show 20 variants DeAuthorized, EmergencyStop, EnergyLimitReached, EVDisconnected, GroundFault, ImmediateReset, MasterPass, Local, LocalOutOfCredit, Other, OvercurrentFault, PowerLoss, PowerQuality, Reboot, Remote, SOCLimitReached, StoppedByEV, TimeLimitReached, Timeout, ReqEnergyTransferRejected,
}
The stoppedReason is the reason/event that initiated the process of stopping the transaction. It will normally be the user stopping authorization via card (Local or MasterPass) or app (Remote), but it can also be CSMS revoking authorization (DeAuthorized), or disconnecting the EV when TxStopPoint = EVConnected (EVDisconnected). Most other reasons are related to technical faults or energy limitations. + MAY only be omitted when stoppedReason is “Local”

Variants



DeAuthorized



EmergencyStop



EnergyLimitReached



EVDisconnected



GroundFault



ImmediateReset



MasterPass



Local



LocalOutOfCredit



Other



OvercurrentFault



PowerLoss



PowerQuality



Reboot



Remote



SOCLimitReached



StoppedByEV



TimeLimitReached



Timeout



ReqEnergyTransferRejected