pub struct APN<CustomDataType = NoCustomData> {
pub apn: String,
pub apn_authentication: APNAuthenticationEnum,
pub apn_password: Option<String<64usize>>,
pub apn_user_name: Option<String<50usize>>,
pub custom_data: Option<CustomDataType>,
pub preferred_network: Option<String<6usize>>,
pub sim_pin: Option<i64>,
pub use_only_preferred_network: Option<bool>,
}Expand description
Collection of configuration data needed to make a data-connection over a cellular network.
NOTE: When asking a GSM modem to dial in, it is possible to specify which mobile operator should be used. This can be done with the mobile country code (MCC) in combination with a mobile network code (MNC). Example: If your preferred network is Vodafone Netherlands, the MCC=204 and the MNC=04 which means the key PreferredNetwork = 20404 Some modems allows to specify a preferred network, which means, if this network is not available, a different network is used. If you specify UseOnlyPreferredNetwork and this network is not available, the modem will not dial in.
Fields
apn: StringThe Access Point Name as an URL.
apn_authentication: APNAuthenticationEnumapn_password: Option<String<64usize>>(2.1) APN Password.
apn_user_name: Option<String<50usize>>APN username.
custom_data: Option<CustomDataType>preferred_network: Option<String<6usize>>Preferred network, written as MCC and MNC concatenated. See note.
sim_pin: Option<i64>SIM card pin code.
use_only_preferred_network: Option<bool>Default: false. Use only the preferred Network, do not dial in when not available. See Note.