pub struct AbsolutePriceSchedule<CustomDataType = NoCustomData> {Show 13 fields
pub additional_selected_services: Option<Vec<AdditionalSelectedServices<CustomDataType>, 5usize>>,
pub currency: String<3usize>,
pub custom_data: Option<CustomDataType>,
pub language: String<8usize>,
pub maximum_cost: Option<RationalNumber<CustomDataType>>,
pub minimum_cost: Option<RationalNumber<CustomDataType>>,
pub overstay_rule_list: Option<OverstayRuleList<CustomDataType>>,
pub price_algorithm: String,
pub price_rule_stacks: Vec<PriceRuleStack<CustomDataType>>,
pub price_schedule_description: Option<String<160usize>>,
pub price_schedule_i_d: i64,
pub tax_rules: Option<Vec<TaxRule<CustomDataType>, 10usize>>,
pub time_anchor: OcppTimestamp,
}Expand description
The AbsolutePriceScheduleType is modeled after the same type that is defined in ISO 15118-20, such that if it is supplied by an EMSP as a signed EXI message, the conversion from EXI to JSON (in OCPP) and back to EXI (for ISO 15118-20) does not change the digest and therefore does not invalidate the signature.
image::images/AbsolutePriceSchedule-Simple.png[]
Fields
additional_selected_services: Option<Vec<AdditionalSelectedServices<CustomDataType>, 5usize>>currency: String<3usize>Currency according to ISO 4217.
custom_data: Option<CustomDataType>language: String<8usize>String that indicates what language is used for the human readable strings in the price schedule. Based on ISO 639.
maximum_cost: Option<RationalNumber<CustomDataType>>minimum_cost: Option<RationalNumber<CustomDataType>>overstay_rule_list: Option<OverstayRuleList<CustomDataType>>price_algorithm: StringA string in URN notation which shall uniquely identify an algorithm that defines how to compute an energy fee sum for a specific power profile based on the EnergyFee information from the PriceRule elements.
price_rule_stacks: Vec<PriceRuleStack<CustomDataType>>price_schedule_description: Option<String<160usize>>Description of the price schedule.
price_schedule_i_d: i64Unique ID of price schedule
tax_rules: Option<Vec<TaxRule<CustomDataType>, 10usize>>time_anchor: OcppTimestampStarting point of price schedule.