pub struct ChargingLimit<CustomDataType = NoCustomData> {
pub charging_limit_source: String<20usize>,
pub custom_data: Option<CustomDataType>,
pub is_grid_critical: Option<bool>,
pub is_local_generation: Option<bool>,
}Fields
charging_limit_source: String<20usize>Represents the source of the charging limit. Values defined in appendix as ChargingLimitSourceEnumStringType.
custom_data: Option<CustomDataType>is_grid_critical: Option<bool>Indicates whether the charging limit is critical for the grid.
is_local_generation: Option<bool>(2.1) True when the reported limit concerns local generation that is providing extra capacity, instead of a limitation.