pub struct ChargingPeriod<CustomDataType = NoCustomData> {
pub custom_data: Option<CustomDataType>,
pub dimensions: Option<Vec<CostDimension<CustomDataType>>>,
pub start_period: OcppTimestamp,
pub tariff_id: Option<String<60usize>>,
}Expand description
A ChargingPeriodType consists of a start time, and a list of possible values that influence this period, for example: amount of energy charged this period, maximum current during this period etc.
Fields
custom_data: Option<CustomDataType>dimensions: Option<Vec<CostDimension<CustomDataType>>>start_period: OcppTimestampStart timestamp of charging period. A period ends when the next period starts. The last period ends when the session ends.
tariff_id: Option<String<60usize>>Unique identifier of the Tariff that was used to calculate cost. If not provided, then cost was calculated by some other means.