ChargingScheduleUpdate

Struct ChargingScheduleUpdate 

pub struct ChargingScheduleUpdate<CustomDataType = NoCustomData> {
Show 13 fields pub custom_data: Option<CustomDataType>, pub discharge_limit: Option<f64>, pub discharge_limit_l2: Option<f64>, pub discharge_limit_l3: Option<f64>, pub limit: Option<f64>, pub limit_l2: Option<f64>, pub limit_l3: Option<f64>, pub setpoint: Option<f64>, pub setpoint_reactive: Option<f64>, pub setpoint_reactive_l2: Option<f64>, pub setpoint_reactive_l3: Option<f64>, pub setpoint_l2: Option<f64>, pub setpoint_l3: Option<f64>,
}
Updates to a ChargingSchedulePeriodType for dynamic charging profiles.

Fields

custom_data: Option<CustomDataType>discharge_limit: Option<f64>

(2.1) Limit in chargingRateUnit that the EV is allowed to discharge with. Note, these are negative values in order to be consistent with setpoint, which can be positive and negative. + For AC this field represents the sum of all phases, unless values are provided for L2 and L3, in which case this field represents phase L1.

discharge_limit_l2: Option<f64>

(2.1) Limit in chargingRateUnit on phase L2 that the EV is allowed to discharge with.

discharge_limit_l3: Option<f64>

(2.1) Limit in chargingRateUnit on phase L3 that the EV is allowed to discharge with.

limit: Option<f64>

Optional only when not required by the operationMode, as in CentralSetpoint, ExternalSetpoint, ExternalLimits, LocalFrequency, LocalLoadBalancing. + Charging rate limit during the schedule period, in the applicable chargingRateUnit. This SHOULD be a non-negative value; a negative value is only supported for backwards compatibility with older systems that use a negative value to specify a discharging limit. For AC this field represents the sum of all phases, unless values are provided for L2 and L3, in which case this field represents phase L1.

limit_l2: Option<f64>

(2.1) Charging rate limit on phase L2 in the applicable chargingRateUnit.

limit_l3: Option<f64>

(2.1) Charging rate limit on phase L3 in the applicable chargingRateUnit.

setpoint: Option<f64>

(2.1) Setpoint in chargingRateUnit that the EV should follow as close as possible. Use negative values for discharging. + When a limit and/or dischargeLimit are given the overshoot when following setpoint must remain within these values. This field represents the sum of all phases, unless values are provided for L2 and L3, in which case this field represents phase L1.

setpoint_reactive: Option<f64>

(2.1) Setpoint for reactive power (or current) in chargingRateUnit that the EV should follow as closely as possible. Positive values for inductive, negative for capacitive reactive power or current. + This field represents the sum of all phases, unless values are provided for L2 and L3, in which case this field represents phase L1.

setpoint_reactive_l2: Option<f64>

(2.1) Setpoint for reactive power (or current) in chargingRateUnit that the EV should follow on phase L2 as closely as possible.

setpoint_reactive_l3: Option<f64>

(2.1) Setpoint for reactive power (or current) in chargingRateUnit that the EV should follow on phase L3 as closely as possible.

setpoint_l2: Option<f64>

(2.1) Setpoint in chargingRateUnit that the EV should follow on phase L2 as close as possible.

setpoint_l3: Option<f64>

(2.1) Setpoint in chargingRateUnit that the EV should follow on phase L3 as close as possible.