pub struct ClearChargingProfile<CustomDataType = NoCustomData> {
pub charging_profile_purpose: Option<ChargingProfilePurposeEnum>,
pub custom_data: Option<CustomDataType>,
pub evse_id: Option<i64>,
pub stack_level: Option<i64>,
}Expand description
A ClearChargingProfileType is a filter for charging profiles to be cleared by ClearChargingProfileRequest.
Fields
charging_profile_purpose: Option<ChargingProfilePurposeEnum>custom_data: Option<CustomDataType>evse_id: Option<i64>Specifies the id of the EVSE for which to clear charging profiles. An evseId of zero (0) specifies the charging profile for the overall Charging Station. Absence of this parameter means the clearing applies to all charging profiles that match the other criteria in the request.
stack_level: Option<i64>Specifies the stackLevel for which charging profiles will be cleared, if they meet the other criteria in the request.