pub struct EVPowerScheduleEntry<CustomDataType = NoCustomData> {
pub custom_data: Option<CustomDataType>,
pub duration: i64,
pub power: f64,
}Expand description
(2.1) An entry in schedule of the energy amount over time that EV is willing to discharge. A negative value indicates the willingness to discharge under specific conditions, a positive value indicates that the EV currently is not able to offer energy to discharge.
Fields
custom_data: Option<CustomDataType>duration: i64The duration of this entry.
power: f64Defines maximum amount of power for the duration of this EVPowerScheduleEntry to be discharged from the EV battery through EVSE power outlet. Negative values are used for discharging.