pub struct FixedVar<CustomDataType = NoCustomData> {
pub custom_data: Option<CustomDataType>,
pub duration: Option<f64>,
pub priority: i64,
pub setpoint: f64,
pub start_time: Option<OcppTimestamp>,
pub unit: DERUnitEnum,
}Fields
custom_data: Option<CustomDataType>duration: Option<f64>Duration in seconds that this setting is active.
priority: i64Priority of setting (0=highest)
setpoint: f64The value specifies a target var output interpreted as a signed percentage (-100 to 100). A negative value refers to charging, whereas a positive one refers to discharging. The value type is determined by the unit field.
start_time: Option<OcppTimestamp>Time when this setting becomes active.
unit: DERUnitEnumTrait Implementations
Sourceimpl<'de, CustomDataType> Deserialize<'de> for FixedVar<CustomDataType>where
CustomDataType: Deserialize<'de>,
impl<'de, CustomDataType> Deserialize<'de> for FixedVar<CustomDataType>where
CustomDataType: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<CustomDataType: PartialEq> StructuralPartialEq for FixedVar<CustomDataType>