pub struct GetVariableResult {
pub attribute_status: GetVariableStatusEnum,
pub attribute_status_info: Option<StatusInfo>,
pub attribute_type: Option<AttributeEnum>,
pub attribute_value: Option<String<2500usize>>,
pub component: Component,
pub custom_data: Option<CustomData>,
pub variable: Variable,
}Expand description
Class to hold results of GetVariables request.
Fields
attribute_status: GetVariableStatusEnumattribute_status_info: Option<StatusInfo>attribute_type: Option<AttributeEnum>attribute_value: Option<String<2500usize>>Value of requested attribute type of component-variable. This field can only be empty when the given status is NOT accepted.
The Configuration Variable <<configkey-reporting-value-size,ReportingValueSize>> can be used to limit GetVariableResult.attributeValue, VariableAttribute.value and EventData.actualValue. The max size of these values will always remain equal.
component: Componentcustom_data: Option<CustomData>variable: VariableTrait Implementations
Sourceimpl Clone for GetVariableResult
impl Clone for GetVariableResult
Sourcefn clone(&self) -> GetVariableResult
fn clone(&self) -> GetVariableResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetVariableResult
impl Debug for GetVariableResult
impl Eq for GetVariableResult
Sourceimpl PartialEq for GetVariableResult
impl PartialEq for GetVariableResult
impl StructuralPartialEq for GetVariableResult