IdToken

Struct IdToken 

pub struct IdToken<CustomDataType = NoCustomData> {
    pub additional_info: Option<Vec<AdditionalInfo<CustomDataType>>>,
    pub custom_data: Option<CustomDataType>,
    pub id_token: String<255usize>,
    pub type: String<20usize>,
}
Contains a case insensitive identifier to use for the authorization and the type of authorization to support multiple forms of identifiers.

Fields

additional_info: Option<Vec<AdditionalInfo<CustomDataType>>>custom_data: Option<CustomDataType>id_token: String<255usize>

(2.1) IdToken is case insensitive. Might hold the hidden id of an RFID tag, but can for example also contain a UUID.

type: String<20usize>

(2.1) Enumeration of possible idToken types. Values defined in Appendix as IdTokenEnumStringType.