LogParameters

Struct LogParameters 

pub struct LogParameters<const LOG_PARAMETERS_LATEST_TIMESTAMP_CAP: usize = 1024, const LOG_PARAMETERS_OLDEST_TIMESTAMP_CAP: usize = 1024> {
    pub custom_data: Option<CustomData>,
    pub latest_timestamp: Option<String<LOG_PARAMETERS_LATEST_TIMESTAMP_CAP>>,
    pub oldest_timestamp: Option<String<LOG_PARAMETERS_OLDEST_TIMESTAMP_CAP>>,
    pub remote_location: String<2000usize>,
}
Generic class for the configuration of logging entries.

Fields

custom_data: Option<CustomData>latest_timestamp: Option<String<LOG_PARAMETERS_LATEST_TIMESTAMP_CAP>>

This contains the date and time of the latest logging information to include in the diagnostics.

oldest_timestamp: Option<String<LOG_PARAMETERS_OLDEST_TIMESTAMP_CAP>>

This contains the date and time of the oldest logging information to include in the diagnostics.

remote_location: String<2000usize>

The URL of the location at the remote system where the log should be stored.