MessageContent

Struct MessageContent 

pub struct MessageContent {
    pub content: String<1024usize>,
    pub custom_data: Option<CustomData>,
    pub format: MessageFormatEnum,
    pub language: Option<String<8usize>>,
}
Contains message details, for a message to be displayed on a Charging Station.

Fields

content: String<1024usize>

(2.1) Required. Message contents. + Maximum length supported by Charging Station is given in OCPPCommCtrlr.FieldLength[“MessageContentType.content”]. Maximum length defaults to 1024.

custom_data: Option<CustomData>format: MessageFormatEnumlanguage: Option<String<8usize>>

Message language identifier. Contains a language code as defined in <<ref-RFC5646,[RFC5646]>>.