pub struct MeterValue<CustomDataType = NoCustomData> {
pub custom_data: Option<CustomDataType>,
pub sampled_value: Vec<SampledValue<CustomDataType>>,
pub timestamp: OcppTimestamp,
}Expand description
Collection of one or more sampled values in MeterValuesRequest and TransactionEvent. All sampled values in a MeterValue are sampled at the same point in time.
Fields
custom_data: Option<CustomDataType>sampled_value: Vec<SampledValue<CustomDataType>>timestamp: OcppTimestampTimestamp for measured value(s).