pub struct NetworkConnectionProfile<CustomDataType = NoCustomData> {
pub apn: Option<APN<CustomDataType>>,
pub basic_auth_password: Option<String<64usize>>,
pub custom_data: Option<CustomDataType>,
pub identity: Option<String<48usize>>,
pub message_timeout: i64,
pub ocpp_csms_url: String,
pub ocpp_interface: OCPPInterfaceEnum,
pub ocpp_transport: OCPPTransportEnum,
pub ocpp_version: Option<OCPPVersionEnum>,
pub security_profile: i64,
pub vpn: Option<VPN<CustomDataType>>,
}Expand description
The NetworkConnectionProfile defines the functional and technical parameters of a communication link.
Fields
apn: Option<APN<CustomDataType>>basic_auth_password: Option<String<64usize>>(2.1) BasicAuthPassword to use for security profile 1 or 2.
custom_data: Option<CustomDataType>identity: Option<String<48usize>>(2.1) Charging Station identity to be used as the basic authentication username.
message_timeout: i64Duration in seconds before a message send by the Charging Station via this network connection times-out. The best setting depends on the underlying network and response times of the CSMS. If you are looking for a some guideline: use 30 seconds as a starting point.
ocpp_csms_url: StringURL of the CSMS(s) that this Charging Station communicates with, without the Charging Station identity part. + The SecurityCtrlr.Identity field is appended to ocppCsmsUrl to provide the full websocket URL.
ocpp_interface: OCPPInterfaceEnumocpp_transport: OCPPTransportEnumocpp_version: Option<OCPPVersionEnum>security_profile: i64This field specifies the security profile used when connecting to the CSMS with this NetworkConnectionProfile.
vpn: Option<VPN<CustomDataType>>Trait Implementations
Sourceimpl<CustomDataType: Clone> Clone for NetworkConnectionProfile<CustomDataType>
impl<CustomDataType: Clone> Clone for NetworkConnectionProfile<CustomDataType>
Sourcefn clone(&self) -> NetworkConnectionProfile<CustomDataType>
fn clone(&self) -> NetworkConnectionProfile<CustomDataType>
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl<CustomDataType: Debug> Debug for NetworkConnectionProfile<CustomDataType>
impl<CustomDataType: Debug> Debug for NetworkConnectionProfile<CustomDataType>
Sourceimpl<'de, CustomDataType> Deserialize<'de> for NetworkConnectionProfile<CustomDataType>where
CustomDataType: Deserialize<'de>,
impl<'de, CustomDataType> Deserialize<'de> for NetworkConnectionProfile<CustomDataType>where
CustomDataType: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
impl<CustomDataType: Eq> Eq for NetworkConnectionProfile<CustomDataType>
Sourceimpl<CustomDataType: PartialEq> PartialEq for NetworkConnectionProfile<CustomDataType>
impl<CustomDataType: PartialEq> PartialEq for NetworkConnectionProfile<CustomDataType>
Sourceimpl<CustomDataType> Serialize for NetworkConnectionProfile<CustomDataType>where
CustomDataType: Serialize,
impl<CustomDataType> Serialize for NetworkConnectionProfile<CustomDataType>where
CustomDataType: Serialize,
impl<CustomDataType: PartialEq> StructuralPartialEq for NetworkConnectionProfile<CustomDataType>
Sourceimpl<CustomDataType> Validate for NetworkConnectionProfile<CustomDataType>
Available on crate features alloc and validate only.
impl<CustomDataType> Validate for NetworkConnectionProfile<CustomDataType>
alloc and validate only.