pub struct OCSPRequestData {
pub custom_data: Option<CustomData>,
pub hash_algorithm: HashAlgorithmEnum,
pub issuer_key_hash: String<128usize>,
pub issuer_name_hash: String<128usize>,
pub responder_u_r_l: String<2000usize>,
pub serial_number: String<40usize>,
}Expand description
Information about a certificate for an OCSP check.
Fields
custom_data: Option<CustomData>hash_algorithm: HashAlgorithmEnumissuer_key_hash: String<128usize>The hash of the DER encoded public key: the value (excluding tag and length) of the subject public key field in the issuer’s certificate.
issuer_name_hash: String<128usize>The hash of the issuer’s distinguished name (DN), that must be calculated over the DER encoding of the issuer’s name field in the certificate being checked.
responder_u_r_l: String<2000usize>This contains the responder URL (Case insensitive).
serial_number: String<40usize>The string representation of the hexadecimal value of the serial number without the prefix “0x” and without leading zeroes.