pub struct PeriodicEventStreamParams {
pub custom_data: Option<CustomData>,
pub interval: Option<i64>,
pub values: Option<i64>,
}Fields
custom_data: Option<CustomData>interval: Option<i64>Time in seconds after which stream data is sent.
values: Option<i64>Number of items to be sent together in stream.