SetMonitoringResult

Struct SetMonitoringResult 

pub struct SetMonitoringResult<CustomDataType = NoCustomData> {
    pub component: Component<CustomDataType>,
    pub custom_data: Option<CustomDataType>,
    pub id: Option<i64>,
    pub severity: i64,
    pub status: SetMonitoringStatusEnum,
    pub status_info: Option<StatusInfo<CustomDataType>>,
    pub type: MonitorEnum,
    pub variable: Variable<CustomDataType>,
}
Class to hold result of SetVariableMonitoring request.

Fields

component: Component<CustomDataType>custom_data: Option<CustomDataType>id: Option<i64>

Id given to the VariableMonitor by the Charging Station. The Id is only returned when status is accepted. Installed VariableMonitors should have unique id’s but the id’s of removed Installed monitors should have unique id’s but the id’s of removed monitors MAY be reused.

severity: i64

The severity that will be assigned to an event that is triggered by this monitor. The severity range is 0-9, with 0 as the highest and 9 as the lowest severity level.

The severity levels have the following meaning: + 0-Danger + Indicates lives are potentially in danger. Urgent attention is needed and action should be taken immediately. + 1-Hardware Failure + Indicates that the Charging Station is unable to continue regular operations due to Hardware issues. Action is required. + 2-System Failure + Indicates that the Charging Station is unable to continue regular operations due to software or minor hardware issues. Action is required. + 3-Critical + Indicates a critical error. Action is required. + 4-Error + Indicates a non-urgent error. Action is required. + 5-Alert + Indicates an alert event. Default severity for any type of monitoring event. + 6-Warning + Indicates a warning event. Action may be required. + 7-Notice + Indicates an unusual event. No immediate action is required. + 8-Informational + Indicates a regular operational event. May be used for reporting, measuring throughput, etc. No action is required. + 9-Debug + Indicates information useful to developers for debugging, not useful during operations.

status: SetMonitoringStatusEnumstatus_info: Option<StatusInfo<CustomDataType>>type: MonitorEnumvariable: Variable<CustomDataType>