pub struct SetVariableData {
pub attribute_type: Option<AttributeEnum>,
pub attribute_value: String<2500usize>,
pub component: Component,
pub custom_data: Option<CustomData>,
pub variable: Variable,
}Fields
attribute_type: Option<AttributeEnum>attribute_value: String<2500usize>Value to be assigned to attribute of variable. This value is allowed to be an empty string (“”).
The Configuration Variable <<configkey-configuration-value-size,ConfigurationValueSize>> can be used to limit SetVariableData.attributeValue and VariableCharacteristics.valuesList. The max size of these values will always remain equal.
component: Componentcustom_data: Option<CustomData>variable: VariableTrait Implementations
Sourceimpl Clone for SetVariableData
impl Clone for SetVariableData
Sourcefn clone(&self) -> SetVariableData
fn clone(&self) -> SetVariableData
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetVariableData
impl Debug for SetVariableData
impl Eq for SetVariableData
Sourceimpl PartialEq for SetVariableData
impl PartialEq for SetVariableData
impl StructuralPartialEq for SetVariableData