pub struct TotalUsage<CustomDataType = NoCustomData> {
pub charging_time: i64,
pub custom_data: Option<CustomDataType>,
pub energy: f64,
pub idle_time: i64,
pub reservation_time: Option<i64>,
}Expand description
This contains the calculated usage of energy, charging time and idle time during a transaction.
Fields
charging_time: i64Total duration of the charging session (including the duration of charging and not charging), in seconds.
custom_data: Option<CustomDataType>energy: f64idle_time: i64Total duration of the charging session where the EV was not charging (no energy was transferred between EVSE and EV), in seconds.
reservation_time: Option<i64>Total time of reservation in seconds.