pub struct Transaction<CustomDataType = NoCustomData> {
pub charging_state: Option<ChargingStateEnum>,
pub custom_data: Option<CustomDataType>,
pub operation_mode: Option<OperationModeEnum>,
pub remote_start_id: Option<i64>,
pub stopped_reason: Option<ReasonEnum>,
pub tariff_id: Option<String<60usize>>,
pub time_spent_charging: Option<i64>,
pub transaction_id: String<36usize>,
pub transaction_limit: Option<TransactionLimit<CustomDataType>>,
}Fields
charging_state: Option<ChargingStateEnum>custom_data: Option<CustomDataType>operation_mode: Option<OperationModeEnum>remote_start_id: Option<i64>The ID given to remote start request (<<requeststarttransactionrequest, RequestStartTransactionRequest>>. This enables to CSMS to match the started transaction to the given start request.
stopped_reason: Option<ReasonEnum>tariff_id: Option<String<60usize>>(2.1) Id of tariff in use for transaction
time_spent_charging: Option<i64>Contains the total time that energy flowed from EVSE to EV during the transaction (in seconds). Note that timeSpentCharging is smaller or equal to the duration of the transaction.
transaction_id: String<36usize>This contains the Id of the transaction.
transaction_limit: Option<TransactionLimit<CustomDataType>>Trait Implementations
Sourceimpl<CustomDataType: Clone> Clone for Transaction<CustomDataType>
impl<CustomDataType: Clone> Clone for Transaction<CustomDataType>
Sourcefn clone(&self) -> Transaction<CustomDataType>
fn clone(&self) -> Transaction<CustomDataType>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<CustomDataType: Debug> Debug for Transaction<CustomDataType>
impl<CustomDataType: Debug> Debug for Transaction<CustomDataType>
Sourceimpl<'de, CustomDataType> Deserialize<'de> for Transaction<CustomDataType>where
CustomDataType: Deserialize<'de>,
impl<'de, CustomDataType> Deserialize<'de> for Transaction<CustomDataType>where
CustomDataType: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<CustomDataType: PartialEq> PartialEq for Transaction<CustomDataType>
impl<CustomDataType: PartialEq> PartialEq for Transaction<CustomDataType>
Sourceimpl<CustomDataType> Serialize for Transaction<CustomDataType>where
CustomDataType: Serialize,
impl<CustomDataType> Serialize for Transaction<CustomDataType>where
CustomDataType: Serialize,
impl<CustomDataType: PartialEq> StructuralPartialEq for Transaction<CustomDataType>
Sourceimpl<CustomDataType> Validate for Transaction<CustomDataType>
Available on crate feature validate only.
impl<CustomDataType> Validate for Transaction<CustomDataType>
Available on crate feature
validate only.Auto Trait Implementations
impl<CustomDataType> Freeze for Transaction<CustomDataType>where
CustomDataType: Freeze,
impl<CustomDataType> RefUnwindSafe for Transaction<CustomDataType>where
CustomDataType: RefUnwindSafe,
impl<CustomDataType> Send for Transaction<CustomDataType>where
CustomDataType: Send,
impl<CustomDataType> Sync for Transaction<CustomDataType>where
CustomDataType: Sync,
impl<CustomDataType> Unpin for Transaction<CustomDataType>where
CustomDataType: Unpin,
impl<CustomDataType> UnsafeUnpin for Transaction<CustomDataType>where
CustomDataType: UnsafeUnpin,
impl<CustomDataType> UnwindSafe for Transaction<CustomDataType>where
CustomDataType: UnwindSafe,