pub struct TransactionLimit<CustomDataType = NoCustomData> {
pub custom_data: Option<CustomDataType>,
pub max_cost: Option<f64>,
pub max_energy: Option<f64>,
pub max_so_c: Option<i64>,
pub max_time: Option<i64>,
}Expand description
Cost, energy, time or SoC limit for a transaction.
Fields
custom_data: Option<CustomDataType>max_cost: Option<f64>Maximum allowed cost of transaction in currency of tariff.
max_energy: Option<f64>Maximum allowed energy in Wh to charge in transaction.
max_so_c: Option<i64>Maximum State of Charge of EV in percentage.
max_time: Option<i64>Maximum duration of transaction in seconds from start to end.