UnitOfMeasure

Struct UnitOfMeasure 

pub struct UnitOfMeasure {
    pub custom_data: Option<CustomData>,
    pub multiplier: Option<i64>,
    pub unit: Option<String<20usize>>,
}
Represents a UnitOfMeasure with a multiplier

Fields

custom_data: Option<CustomData>multiplier: Option<i64>

Multiplier, this value represents the exponent to base 10. I.e. multiplier 3 means 10 raised to the 3rd power. Default is 0. + The multiplier only multiplies the value of the measurand. It does not specify a conversion between units, for example, kW and W.

unit: Option<String<20usize>>

Unit of the value. Default = “Wh” if the (default) measurand is an “Energy” type. This field SHALL use a value from the list Standardized Units of Measurements in Part 2 Appendices. If an applicable unit is available in that list, otherwise a “custom” unit might be used.