pub struct BootNotificationResponse<const BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP: usize = 1024> {
pub current_time: String<BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP>,
pub custom_data: Option<CustomData>,
pub interval: i64,
pub status: RegistrationStatusEnum,
pub status_info: Option<StatusInfo>,
}Fields
current_time: String<BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP>This contains the CSMS’s current time.
custom_data: Option<CustomData>interval: i64When <<cmn_registrationstatusenumtype,Status>> is Accepted, this contains the heartbeat interval in seconds. If the CSMS returns something other than Accepted, the value of the interval field indicates the minimum wait time before sending a next BootNotification request.
status: RegistrationStatusEnumstatus_info: Option<StatusInfo>Trait Implementations
Sourceimpl<const BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP: usize> Action for BootNotificationResponse<BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP>
Available on non-crate feature alloc only.
impl<const BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP: usize> Action for BootNotificationResponse<BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP>
Available on non-crate feature
alloc only.Sourceimpl<const BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP: usize> Clone for BootNotificationResponse<BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP>
impl<const BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP: usize> Clone for BootNotificationResponse<BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP>
Sourcefn clone(
&self,
) -> BootNotificationResponse<BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP>
fn clone( &self, ) -> BootNotificationResponse<BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<const BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP: usize> Debug for BootNotificationResponse<BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP>
impl<const BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP: usize> Debug for BootNotificationResponse<BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP>
impl<const BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP: usize> Eq for BootNotificationResponse<BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP>
Sourceimpl<const BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP: usize> PartialEq for BootNotificationResponse<BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP>
impl<const BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP: usize> PartialEq for BootNotificationResponse<BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP>
impl<const BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP: usize> StructuralPartialEq for BootNotificationResponse<BOOT_NOTIFICATION_RESPONSE_CURRENT_TIME_CAP>