CertificateSignedRequest

Struct CertificateSignedRequest 

pub struct CertificateSignedRequest<CustomDataType = NoCustomData> {
    pub certificate_chain: String,
    pub certificate_type: Option<CertificateSigningUseEnum>,
    pub custom_data: Option<CustomDataType>,
    pub request_id: Option<i64>,
}

Fields

certificate_chain: String

The signed PEM encoded X.509 certificate. This SHALL also contain the necessary sub CA certificates, when applicable. The order of the bundle follows the certificate chain, starting from the leaf certificate.

The Configuration Variable <<configkey-max-certificate-chain-size,MaxCertificateChainSize>> can be used to limit the maximum size of this field.

certificate_type: Option<CertificateSigningUseEnum>custom_data: Option<CustomDataType>request_id: Option<i64>

(2.1) RequestId to correlate this message with the SignCertificateRequest.