Get15118EVCertificateRequest

Struct Get15118EVCertificateRequest 

pub struct Get15118EVCertificateRequest {
    pub action: CertificateActionEnum,
    pub custom_data: Option<CustomData>,
    pub exi_request: String<11000usize>,
    pub iso15118_schema_version: String<50usize>,
    pub maximum_contract_certificate_chains: Option<i64>,
    pub prioritized_e_m_a_i_ds: Option<Vec<String<255usize>, 8usize>>,
}

Fields

action: CertificateActionEnumcustom_data: Option<CustomData>exi_request: String<11000usize>

(2.1) Raw CertificateInstallationReq request from EV, Base64 encoded. + Extended to support ISO 15118-20 certificates. The minimum supported length is 11000. If a longer exiRequest is supported, then the supported length must be communicated in variable OCPPCommCtrlr.FieldLength[ “Get15118EVCertificateRequest.exiRequest” ].

iso15118_schema_version: String<50usize>

Schema version currently used for the 15118 session between EV and Charging Station. Needed for parsing of the EXI stream by the CSMS.

maximum_contract_certificate_chains: Option<i64>

(2.1) Absent during ISO 15118-2 session. Required during ISO 15118-20 session. + Maximum number of contracts that EV wants to install.

prioritized_e_m_a_i_ds: Option<Vec<String<255usize>, 8usize>>

(2.1) Absent during ISO 15118-2 session. Optional during ISO 15118-20 session. List of EMAIDs for which contract certificates must be requested first, in case there are more certificates than allowed by maximumContractCertificateChains.