pub struct Get15118EVCertificateResponse {
pub custom_data: Option<CustomData>,
pub exi_response: String<17000usize>,
pub remaining_contracts: Option<i64>,
pub status: Iso15118EVCertificateStatusEnum,
pub status_info: Option<StatusInfo>,
}Fields
custom_data: Option<CustomData>exi_response: String<17000usize>(2/1) Raw CertificateInstallationRes response for the EV, Base64 encoded. + Extended to support ISO 15118-20 certificates. The minimum supported length is 17000. If a longer exiResponse is supported, then the supported length must be communicated in variable OCPPCommCtrlr.FieldLength[ “Get15118EVCertificateResponse.exiResponse” ].
remaining_contracts: Option<i64>(2.1) Number of contracts that can be retrieved with additional requests.
status: Iso15118EVCertificateStatusEnumstatus_info: Option<StatusInfo>Trait Implementations
Sourceimpl Clone for Get15118EVCertificateResponse
impl Clone for Get15118EVCertificateResponse
Sourcefn clone(&self) -> Get15118EVCertificateResponse
fn clone(&self) -> Get15118EVCertificateResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for Get15118EVCertificateResponse
impl StructuralPartialEq for Get15118EVCertificateResponse