pub struct GetLogRequest<CustomDataType = NoCustomData> {
pub custom_data: Option<CustomDataType>,
pub log: LogParameters<CustomDataType>,
pub log_type: LogEnum,
pub request_id: i64,
pub retries: Option<i64>,
pub retry_interval: Option<i64>,
}Fields
custom_data: Option<CustomDataType>log: LogParameters<CustomDataType>log_type: LogEnumrequest_id: i64The Id of this request
retries: Option<i64>This specifies how many times the Charging Station must retry to upload the log before giving up. If this field is not present, it is left to Charging Station to decide how many times it wants to retry. If the value is 0, it means: no retries.
retry_interval: Option<i64>The interval in seconds after which a retry may be attempted. If this field is not present, it is left to Charging Station to decide how long to wait between attempts.