pub struct NotifyAllowedEnergyTransferRequest<const NOTIFY_ALLOWED_ENERGY_TRANSFER_REQUEST_ALLOWED_ENERGY_TRANSFER_CAP: usize = 16> {
pub allowed_energy_transfer: Vec<EnergyTransferModeEnum, NOTIFY_ALLOWED_ENERGY_TRANSFER_REQUEST_ALLOWED_ENERGY_TRANSFER_CAP>,
pub custom_data: Option<CustomData>,
pub transaction_id: String<36usize>,
}Fields
allowed_energy_transfer: Vec<EnergyTransferModeEnum, NOTIFY_ALLOWED_ENERGY_TRANSFER_REQUEST_ALLOWED_ENERGY_TRANSFER_CAP>Modes of energy transfer that are accepted by CSMS.
custom_data: Option<CustomData>transaction_id: String<36usize>The transaction for which the allowed energy transfer is allowed.