NotifyPeriodicEventStream

Struct NotifyPeriodicEventStream 

pub struct NotifyPeriodicEventStream<const NOTIFY_PERIODIC_EVENT_STREAM_BASETIME_CAP: usize = 1024, const NOTIFY_PERIODIC_EVENT_STREAM_DATA_CAP: usize = 16> {
    pub basetime: String<NOTIFY_PERIODIC_EVENT_STREAM_BASETIME_CAP>,
    pub custom_data: Option<CustomData>,
    pub data: Vec<StreamDataElement, NOTIFY_PERIODIC_EVENT_STREAM_DATA_CAP>,
    pub id: i64,
    pub pending: i64,
}

Fields

basetime: String<NOTIFY_PERIODIC_EVENT_STREAM_BASETIME_CAP>

Base timestamp to add to time offset of values.

custom_data: Option<CustomData>data: Vec<StreamDataElement, NOTIFY_PERIODIC_EVENT_STREAM_DATA_CAP>id: i64

Id of stream.

pending: i64

Number of data elements still pending to be sent.