NotifySettlementResponse

Struct NotifySettlementResponse 

pub struct NotifySettlementResponse {
    pub custom_data: Option<CustomData>,
    pub receipt_id: Option<String<50usize>>,
    pub receipt_url: Option<String<2000usize>>,
}

Fields

custom_data: Option<CustomData>receipt_id: Option<String<50usize>>

The receipt id if the receipt is generated by CSMS.

receipt_url: Option<String<2000usize>>

The receipt URL if receipt generated by CSMS. The Charging Station can QR encode it and show it to the EV Driver.