PublishFirmwareRequest

Struct PublishFirmwareRequest 

pub struct PublishFirmwareRequest {
    pub checksum: String<32usize>,
    pub custom_data: Option<CustomData>,
    pub location: String<2000usize>,
    pub request_id: i64,
    pub retries: Option<i64>,
    pub retry_interval: Option<i64>,
}

Fields

checksum: String<32usize>

The MD5 checksum over the entire firmware file as a hexadecimal string of length 32.

custom_data: Option<CustomData>location: String<2000usize>

This contains a string containing a URI pointing to a location from which to retrieve the firmware.

request_id: i64

The Id of the request.

retries: Option<i64>

This specifies how many times Charging Station must retry to download the firmware before giving up. If this field is not present, it is left to Charging Station to decide how many times it wants to retry. If the value is 0, it means: no retries.

retry_interval: Option<i64>

The interval in seconds after which a retry may be attempted. If this field is not present, it is left to Charging Station to decide how long to wait between attempts.