TransactionEventRequest

Struct TransactionEventRequest 

pub struct TransactionEventRequest<CustomDataType = NoCustomData> {
Show 16 fields pub cable_max_current: Option<i64>, pub cost_details: Option<CostDetails<CustomDataType>>, pub custom_data: Option<CustomDataType>, pub event_type: TransactionEventEnum, pub evse: Option<EVSE<CustomDataType>>, pub evse_sleep: Option<bool>, pub id_token: Option<IdToken<CustomDataType>>, pub meter_value: Option<Vec<MeterValue<CustomDataType>>>, pub number_of_phases_used: Option<i64>, pub offline: Option<bool>, pub preconditioning_status: Option<PreconditioningStatusEnum>, pub reservation_id: Option<i64>, pub seq_no: i64, pub timestamp: OcppTimestamp, pub transaction_info: Transaction<CustomDataType>, pub trigger_reason: TriggerReasonEnum,
}

Fields

cable_max_current: Option<i64>

The maximum current of the connected cable in Ampere (A).

cost_details: Option<CostDetails<CustomDataType>>custom_data: Option<CustomDataType>event_type: TransactionEventEnumevse: Option<EVSE<CustomDataType>>evse_sleep: Option<bool>

(2.1) True when EVSE electronics are in sleep mode for this transaction. Default value (when absent) is false.

id_token: Option<IdToken<CustomDataType>>meter_value: Option<Vec<MeterValue<CustomDataType>>>number_of_phases_used: Option<i64>

If the Charging Station is able to report the number of phases used, then it SHALL provide it. When omitted the CSMS may be able to determine the number of phases used as follows: + 1: The numberPhases in the currently used ChargingSchedule. + 2: The number of phases provided via device management.

offline: Option<bool>

Indication that this transaction event happened when the Charging Station was offline. Default = false, meaning: the event occurred when the Charging Station was online.

preconditioning_status: Option<PreconditioningStatusEnum>reservation_id: Option<i64>

This contains the Id of the reservation that terminates as a result of this transaction.

seq_no: i64

Incremental sequence number, helps with determining if all messages of a transaction have been received.

timestamp: OcppTimestamp

The date and time at which this transaction event occurred.

transaction_info: Transaction<CustomDataType>trigger_reason: TriggerReasonEnum