TransactionEventResponse

Struct TransactionEventResponse 

pub struct TransactionEventResponse<CustomDataType = NoCustomData> {
    pub charging_priority: Option<i64>,
    pub custom_data: Option<CustomDataType>,
    pub id_token_info: Option<IdTokenInfo<CustomDataType>>,
    pub total_cost: Option<f64>,
    pub transaction_limit: Option<TransactionLimit<CustomDataType>>,
    pub updated_personal_message: Option<MessageContent<CustomDataType>>,
    pub updated_personal_message_extra: Option<Vec<MessageContent<CustomDataType>, 4usize>>,
}

Fields

charging_priority: Option<i64>

Priority from a business point of view. Default priority is 0, The range is from -9 to 9. Higher values indicate a higher priority. The chargingPriority in <<transactioneventresponse,TransactionEventResponse>> is temporarily, so it may not be set in the <<cmn_idtokeninfotype,IdTokenInfoType>> afterwards. Also the chargingPriority in <<transactioneventresponse,TransactionEventResponse>> has a higher priority than the one in <<cmn_idtokeninfotype,IdTokenInfoType>>.

custom_data: Option<CustomDataType>id_token_info: Option<IdTokenInfo<CustomDataType>>total_cost: Option<f64>

When eventType of TransactionEventRequest is Updated, then this value contains the running cost. When eventType of TransactionEventRequest is Ended, then this contains the final total cost of this transaction, including taxes, in the currency configured with the Configuration Variable: Currency. Absence of this value does not imply that the transaction was free. To indicate a free transaction, the CSMS SHALL send a value of 0.00.

transaction_limit: Option<TransactionLimit<CustomDataType>>updated_personal_message: Option<MessageContent<CustomDataType>>updated_personal_message_extra: Option<Vec<MessageContent<CustomDataType>, 4usize>>