Charging_ Profile
urn:x-oca:ocpp:uid:2:233255
A ChargingProfile consists of ChargingSchedule, describing the amount of power or current that can be delivered per time interval.
Charging_ Profile
urn:x-oca:ocpp:uid:2:233255
A ChargingProfile consists of ChargingSchedule, describing the amount of power or current that can be delivered per time interval.
Charging_ Schedule
urn:x-oca:ocpp:uid:2:233256
Charging schedule structure defines a list of charging periods, as used in: GetCompositeSchedule.conf and ChargingProfile.
Charging_ Profile
urn:x-oca:ocpp:uid:2:233255
A ChargingProfile consists of a ChargingSchedule, describing the amount of power or current that can be delivered per time interval.
This class does not get ‘AdditionalProperties = false’ in the schema generation, so it can be extended with arbitrary JSON properties to allow adding custom data.
ID_ Token
urn:x-oca:ocpp:uid:2:233247
Contains status information about an identifier.
It is advised to not stop charging for a token that expires during charging, as ExpiryDate is only used for caching purposes. If ExpiryDate is not given, the status has no end date.
Meter_ Value
urn:x-oca:ocpp:uid:2:233265
Collection of one or more sampled values in MeterValuesRequest and TransactionEvent. All sampled values in a MeterValue are sampled at the same point in time.
Wireless_ Communication_ Module
urn:x-oca:ocpp:uid:2:233306
Defines parameters required for initiating and maintaining wireless communication with other devices.
Communication_ Function
urn:x-oca:ocpp:uid:2:233304
The NetworkConnectionProfile defines the functional and technical parameters of a communication link.
Indicates the type of the signed certificate that is returned. When omitted the certificate is used for both the 15118 connection (if implemented) and the Charging Station to CSMS connection. This field is required when a typeOfCertificate was included in the <<signcertificaterequest,SignCertificateRequest>> that requested this certificate to be signed AND both the 15118 connection and the Charging Station connection are implemented.
Charging_ Profile. Charging_ Profile_ Purpose. Charging_ Profile_ Purpose_ Code
urn:x-oca:ocpp:uid:1:569231
Specifies to purpose of the charging profiles that will be cleared, if they meet the other criteria in the request.
Returns whether the Charging Station has been able to process the message successfully. This does not guarantee the schedule will be followed to the letter. There might be other constraints the Charging Station may need to take into account.
This indicates whether the Charging Station is able to process this request and will send <<reportchargingprofilesrequest, ReportChargingProfilesRequest>> messages.
Returns whether the CSMS has been able to process the message successfully. It does not imply that the evChargingNeeds can be met with the current charging profile.
Communication_ Function. OCPP_ Transport. OCPP_ Transport_ Code
urn:x-oca:ocpp:uid:1:569356
Defines the transport protocol (e.g. SOAP or JSON). Note: SOAP is not supported in OCPP 2.0, but is supported by other versions of OCPP.
Sampled_ Value. Phase. Phase_ Code
urn:x-oca:ocpp:uid:1:569264
Indicates how the measured value is to be interpreted. For instance between L1 and neutral (L1-N) Please note that not all values of phase are applicable to all Measurands. When phase is absent, the measured value is interpreted as an overall value.
Transaction. Stopped_ Reason. EOT_ Reason_ Code
urn:x-oca:ocpp:uid:1:569413
This contains the reason why the transaction was stopped. MAY only be omitted when Reason is “Local”.
This contains the type of this event.
The first TransactionEvent of a transaction SHALL contain: “Started” The last TransactionEvent of a transaction SHALL contain: “Ended” All others SHALL contain: “Updated”