pub enum PhaseEnum {
L1,
L2,
L3,
N,
L1N,
L2N,
L3N,
L1L2,
L2L3,
L3L1,
}Expand description
Sampled_ Value. Phase. Phase_ Code urn:x-oca:ocpp:uid:1:569264 Indicates how the measured value is to be interpreted. For instance between L1 and neutral (L1-N) Please note that not all values of phase are applicable to all Measurands. When phase is absent, the measured value is interpreted as an overall value.
Variants