pub struct APN {
pub apn: String<512usize>,
pub apn_authentication: APNAuthenticationEnum,
pub apn_password: Option<String<20usize>>,
pub apn_user_name: Option<String<20usize>>,
pub custom_data: Option<CustomData>,
pub preferred_network: Option<String<6usize>>,
pub sim_pin: Option<i64>,
pub use_only_preferred_network: Option<bool>,
}Expand description
APN urn:x-oca:ocpp:uid:2:233134 Collection of configuration data needed to make a data-connection over a cellular network.
NOTE: When asking a GSM modem to dial in, it is possible to specify which mobile operator should be used. This can be done with the mobile country code (MCC) in combination with a mobile network code (MNC). Example: If your preferred network is Vodafone Netherlands, the MCC=204 and the MNC=04 which means the key PreferredNetwork = 20404 Some modems allows to specify a preferred network, which means, if this network is not available, a different network is used. If you specify UseOnlyPreferredNetwork and this network is not available, the modem will not dial in.
Fields
apn: String<512usize>APN. APN. URI urn:x-oca:ocpp:uid:1:568814 The Access Point Name as an URL.
apn_authentication: APNAuthenticationEnumapn_password: Option<String<20usize>>APN. APN. Password urn:x-oca:ocpp:uid:1:568819 APN Password.
apn_user_name: Option<String<20usize>>APN. APN. User_ Name urn:x-oca:ocpp:uid:1:568818 APN username.
custom_data: Option<CustomData>preferred_network: Option<String<6usize>>APN. Preferred_ Network. Mobile_ Network_ ID urn:x-oca:ocpp:uid:1:568822 Preferred network, written as MCC and MNC concatenated. See note.
sim_pin: Option<i64>APN. SIMPIN. PIN_ Code urn:x-oca:ocpp:uid:1:568821 SIM card pin code.
use_only_preferred_network: Option<bool>APN. Use_ Only_ Preferred_ Network. Indicator urn:x-oca:ocpp:uid:1:568824 Default: false. Use only the preferred Network, do not dial in when not available. See Note.