pub struct ChargingProfile<const CHARGING_SCHEDULE_START_SCHEDULE_CAP: usize = 1024, const CHARGING_PROFILE_VALID_FROM_CAP: usize = 1024, const CHARGING_PROFILE_VALID_TO_CAP: usize = 1024> {
pub charging_profile_kind: ChargingProfileKindEnum,
pub charging_profile_purpose: ChargingProfilePurposeEnum,
pub charging_schedule: Vec<ChargingSchedule<CHARGING_SCHEDULE_START_SCHEDULE_CAP>, 3usize>,
pub custom_data: Option<CustomData>,
pub id: i64,
pub recurrency_kind: Option<RecurrencyKindEnum>,
pub stack_level: i64,
pub transaction_id: Option<String<36usize>>,
pub valid_from: Option<String<CHARGING_PROFILE_VALID_FROM_CAP>>,
pub valid_to: Option<String<CHARGING_PROFILE_VALID_TO_CAP>>,
}Expand description
Charging_ Profile urn:x-oca:ocpp:uid:2:233255 A ChargingProfile consists of ChargingSchedule, describing the amount of power or current that can be delivered per time interval.
Fields
charging_profile_kind: ChargingProfileKindEnumcharging_profile_purpose: ChargingProfilePurposeEnumcharging_schedule: Vec<ChargingSchedule<CHARGING_SCHEDULE_START_SCHEDULE_CAP>, 3usize>custom_data: Option<CustomData>id: i64Identified_ Object. MRID. Numeric_ Identifier urn:x-enexis:ecdm:uid:1:569198 Id of ChargingProfile.
recurrency_kind: Option<RecurrencyKindEnum>stack_level: i64Charging_ Profile. Stack_ Level. Counter urn:x-oca:ocpp:uid:1:569230 Value determining level in hierarchy stack of profiles. Higher values have precedence over lower values. Lowest level is 0.
transaction_id: Option<String<36usize>>SHALL only be included if ChargingProfilePurpose is set to TxProfile. The transactionId is used to match the profile to a specific transaction.
valid_from: Option<String<CHARGING_PROFILE_VALID_FROM_CAP>>Charging_ Profile. Valid_ From. Date_ Time urn:x-oca:ocpp:uid:1:569234 Point in time at which the profile starts to be valid. If absent, the profile is valid as soon as it is received by the Charging Station.
valid_to: Option<String<CHARGING_PROFILE_VALID_TO_CAP>>Charging_ Profile. Valid_ To. Date_ Time urn:x-oca:ocpp:uid:1:569235 Point in time at which the profile stops to be valid. If absent, the profile is valid until it is replaced by another profile.