pub struct ChargingProfileCriterion<CustomDataType = NoCustomData> {
pub charging_limit_source: Option<Vec<ChargingLimitSourceEnum, 4usize>>,
pub charging_profile_id: Option<Vec<i64>>,
pub charging_profile_purpose: Option<ChargingProfilePurposeEnum>,
pub custom_data: Option<CustomDataType>,
pub stack_level: Option<i64>,
}Expand description
Charging_ Profile urn:x-oca:ocpp:uid:2:233255 A ChargingProfile consists of ChargingSchedule, describing the amount of power or current that can be delivered per time interval.
Fields
charging_limit_source: Option<Vec<ChargingLimitSourceEnum, 4usize>>For which charging limit sources, charging profiles SHALL be reported. If omitted, the Charging Station SHALL not filter on chargingLimitSource.
charging_profile_id: Option<Vec<i64>>List of all the chargingProfileIds requested. Any ChargingProfile that matches one of these profiles will be reported. If omitted, the Charging Station SHALL not filter on chargingProfileId. This field SHALL NOT contain more ids than set in <<configkey-charging-profile-entries,ChargingProfileEntries.maxLimit>>
charging_profile_purpose: Option<ChargingProfilePurposeEnum>custom_data: Option<CustomDataType>stack_level: Option<i64>Charging_ Profile. Stack_ Level. Counter urn:x-oca:ocpp:uid:1:569230 Value determining level in hierarchy stack of profiles. Higher values have precedence over lower values. Lowest level is 0.