ChargingSchedule

Struct ChargingSchedule 

pub struct ChargingSchedule<const CHARGING_SCHEDULE_START_SCHEDULE_CAP: usize = 1024> {
    pub charging_rate_unit: ChargingRateUnitEnum,
    pub charging_schedule_period: Vec<ChargingSchedulePeriod, 1024usize>,
    pub custom_data: Option<CustomData>,
    pub duration: Option<i64>,
    pub id: i64,
    pub min_charging_rate: Option<f64>,
    pub sales_tariff: Option<SalesTariff>,
    pub start_schedule: Option<String<CHARGING_SCHEDULE_START_SCHEDULE_CAP>>,
}
Charging_ Schedule urn:x-oca:ocpp:uid:2:233256 Charging schedule structure defines a list of charging periods, as used in: GetCompositeSchedule.conf and ChargingProfile.

Fields

charging_rate_unit: ChargingRateUnitEnumcharging_schedule_period: Vec<ChargingSchedulePeriod, 1024usize>custom_data: Option<CustomData>duration: Option<i64>

Charging_ Schedule. Duration. Elapsed_ Time urn:x-oca:ocpp:uid:1:569236 Duration of the charging schedule in seconds. If the duration is left empty, the last period will continue indefinitely or until end of the transaction if chargingProfilePurpose = TxProfile.

id: i64

Identifies the ChargingSchedule.

min_charging_rate: Option<f64>

Charging_ Schedule. Min_ Charging_ Rate. Numeric urn:x-oca:ocpp:uid:1:569239 Minimum charging rate supported by the EV. The unit of measure is defined by the chargingRateUnit. This parameter is intended to be used by a local smart charging algorithm to optimize the power allocation for in the case a charging process is inefficient at lower charging rates. Accepts at most one digit fraction (e.g. 8.1)

sales_tariff: Option<SalesTariff>start_schedule: Option<String<CHARGING_SCHEDULE_START_SCHEDULE_CAP>>

Charging_ Schedule. Start_ Schedule. Date_ Time urn:x-oca:ocpp:uid:1:569237 Starting point of an absolute schedule. If absent the schedule will be relative to start of charging.