pub struct ClearChargingProfile<CustomDataType = NoCustomData> {
pub charging_profile_purpose: Option<ChargingProfilePurposeEnum>,
pub custom_data: Option<CustomDataType>,
pub evse_id: Option<i64>,
pub stack_level: Option<i64>,
}Expand description
Charging_ Profile urn:x-oca:ocpp:uid:2:233255 A ChargingProfile consists of a ChargingSchedule, describing the amount of power or current that can be delivered per time interval.
Fields
charging_profile_purpose: Option<ChargingProfilePurposeEnum>custom_data: Option<CustomDataType>evse_id: Option<i64>Identified_ Object. MRID. Numeric_ Identifier urn:x-enexis:ecdm:uid:1:569198 Specifies the id of the EVSE for which to clear charging profiles. An evseId of zero (0) specifies the charging profile for the overall Charging Station. Absence of this parameter means the clearing applies to all charging profiles that match the other criteria in the request.
stack_level: Option<i64>Charging_ Profile. Stack_ Level. Counter urn:x-oca:ocpp:uid:1:569230 Specifies the stackLevel for which charging profiles will be cleared, if they meet the other criteria in the request.