pub struct ConsumptionCost {
pub cost: Vec<Cost, 3usize>,
pub custom_data: Option<CustomData>,
pub start_value: f64,
}Expand description
Consumption_ Cost urn:x-oca:ocpp:uid:2:233259
Fields
cost: Vec<Cost, 3usize>custom_data: Option<CustomData>start_value: f64Consumption_ Cost. Start_ Value. Numeric urn:x-oca:ocpp:uid:1:569246 The lowest level of consumption that defines the starting point of this consumption block. The block interval extends to the start of the next interval.