pub struct MessageInfo<const MESSAGE_INFO_END_DATE_TIME_CAP: usize = 1024, const MESSAGE_INFO_START_DATE_TIME_CAP: usize = 1024> {
pub custom_data: Option<CustomData>,
pub display: Option<Component>,
pub end_date_time: Option<String<MESSAGE_INFO_END_DATE_TIME_CAP>>,
pub id: i64,
pub message: MessageContent,
pub priority: MessagePriorityEnum,
pub start_date_time: Option<String<MESSAGE_INFO_START_DATE_TIME_CAP>>,
pub state: Option<MessageStateEnum>,
pub transaction_id: Option<String<36usize>>,
}Expand description
Message_ Info urn:x-enexis:ecdm:uid:2:233264 Contains message details, for a message to be displayed on a Charging Station.
Fields
custom_data: Option<CustomData>display: Option<Component>end_date_time: Option<String<MESSAGE_INFO_END_DATE_TIME_CAP>>Message_ Info. End. Date_ Time urn:x-enexis:ecdm:uid:1:569257 Until what date-time should this message be shown, after this date/time this message SHALL be removed.
id: i64Identified_ Object. MRID. Numeric_ Identifier urn:x-enexis:ecdm:uid:1:569198 Master resource identifier, unique within an exchange context. It is defined within the OCPP context as a positive Integer value (greater or equal to zero).
message: MessageContentpriority: MessagePriorityEnumstart_date_time: Option<String<MESSAGE_INFO_START_DATE_TIME_CAP>>Message_ Info. Start. Date_ Time urn:x-enexis:ecdm:uid:1:569256 From what date-time should this message be shown. If omitted: directly.
state: Option<MessageStateEnum>transaction_id: Option<String<36usize>>During which transaction shall this message be shown. Message SHALL be removed by the Charging Station after transaction has ended.