pub struct NetworkConnectionProfile {
pub apn: Option<APN>,
pub custom_data: Option<CustomData>,
pub message_timeout: i64,
pub ocpp_csms_url: String<512usize>,
pub ocpp_interface: OCPPInterfaceEnum,
pub ocpp_transport: OCPPTransportEnum,
pub ocpp_version: OCPPVersionEnum,
pub security_profile: i64,
pub vpn: Option<VPN>,
}Expand description
Communication_ Function urn:x-oca:ocpp:uid:2:233304 The NetworkConnectionProfile defines the functional and technical parameters of a communication link.
Fields
apn: Option<APN>custom_data: Option<CustomData>message_timeout: i64Duration in seconds before a message send by the Charging Station via this network connection times-out. The best setting depends on the underlying network and response times of the CSMS. If you are looking for a some guideline: use 30 seconds as a starting point.
ocpp_csms_url: String<512usize>Communication_ Function. OCPP_ Central_ System_ URL. URI urn:x-oca:ocpp:uid:1:569357 URL of the CSMS(s) that this Charging Station communicates with.
ocpp_interface: OCPPInterfaceEnumocpp_transport: OCPPTransportEnumocpp_version: OCPPVersionEnumsecurity_profile: i64This field specifies the security profile used when connecting to the CSMS with this NetworkConnectionProfile.
vpn: Option<VPN>Trait Implementations
Sourceimpl Clone for NetworkConnectionProfile
impl Clone for NetworkConnectionProfile
Sourcefn clone(&self) -> NetworkConnectionProfile
fn clone(&self) -> NetworkConnectionProfile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NetworkConnectionProfile
impl Debug for NetworkConnectionProfile
impl Eq for NetworkConnectionProfile
Sourceimpl PartialEq for NetworkConnectionProfile
impl PartialEq for NetworkConnectionProfile
impl StructuralPartialEq for NetworkConnectionProfile