SalesTariff

Struct SalesTariff 

pub struct SalesTariff<CustomDataType = NoCustomData> {
    pub custom_data: Option<CustomDataType>,
    pub id: i64,
    pub num_e_price_levels: Option<i64>,
    pub sales_tariff_description: Option<String<32usize>>,
    pub sales_tariff_entry: Vec<SalesTariffEntry<CustomDataType>>,
}
Sales_ Tariff urn:x-oca:ocpp:uid:2:233272 NOTE: This dataType is based on dataTypes from <<ref-ISOIEC15118-2,ISO 15118-2>>.

Fields

custom_data: Option<CustomDataType>id: i64

Identified_ Object. MRID. Numeric_ Identifier urn:x-enexis:ecdm:uid:1:569198 SalesTariff identifier used to identify one sales tariff. An SAID remains a unique identifier for one schedule throughout a charging session.

num_e_price_levels: Option<i64>

Sales_ Tariff. Num_ E_ Price_ Levels. Counter urn:x-oca:ocpp:uid:1:569284 Defines the overall number of distinct price levels used across all provided SalesTariff elements.

sales_tariff_description: Option<String<32usize>>

Sales_ Tariff. Sales. Tariff_ Description urn:x-oca:ocpp:uid:1:569283 A human readable title/short description of the sales tariff e.g. for HMI display purposes.

sales_tariff_entry: Vec<SalesTariffEntry<CustomDataType>>