SampledValue

Struct SampledValue 

pub struct SampledValue {
    pub context: Option<ReadingContextEnum>,
    pub custom_data: Option<CustomData>,
    pub location: Option<LocationEnum>,
    pub measurand: Option<MeasurandEnum>,
    pub phase: Option<PhaseEnum>,
    pub signed_meter_value: Option<SignedMeterValue>,
    pub unit_of_measure: Option<UnitOfMeasure>,
    pub value: f64,
}
Sampled_ Value urn:x-oca:ocpp:uid:2:233266 Single sampled value in MeterValues. Each value can be accompanied by optional fields.

To save on mobile data usage, default values of all of the optional fields are such that. The value without any additional fields will be interpreted, as a register reading of active import energy in Wh (Watt-hour) units.

Fields

context: Option<ReadingContextEnum>custom_data: Option<CustomData>location: Option<LocationEnum>measurand: Option<MeasurandEnum>phase: Option<PhaseEnum>signed_meter_value: Option<SignedMeterValue>unit_of_measure: Option<UnitOfMeasure>value: f64

Sampled_ Value. Value. Measure urn:x-oca:ocpp:uid:1:569260 Indicates the measured value.