pub struct SignedMeterValue {
pub custom_data: Option<CustomData>,
pub encoding_method: String<50usize>,
pub public_key: String<2500usize>,
pub signed_meter_data: String<2500usize>,
pub signing_method: String<50usize>,
}Expand description
Represent a signed version of the meter value.
Fields
custom_data: Option<CustomData>encoding_method: String<50usize>Method used to encode the meter values before applying the digital signature algorithm.
public_key: String<2500usize>Base64 encoded, sending depends on configuration variable PublicKeyWithSignedMeterValue.
signed_meter_data: String<2500usize>Base64 encoded, contains the signed data which might contain more then just the meter value. It can contain information like timestamps, reference to a customer etc.
signing_method: String<50usize>Method used to create the digital signature.