pub struct GetChargingProfilesRequest<CustomDataType = NoCustomData> {
pub charging_profile: ChargingProfileCriterion<CustomDataType>,
pub custom_data: Option<CustomDataType>,
pub evse_id: Option<i64>,
pub request_id: i64,
}Fields
charging_profile: ChargingProfileCriterion<CustomDataType>custom_data: Option<CustomDataType>evse_id: Option<i64>For which EVSE installed charging profiles SHALL be reported. If 0, only charging profiles installed on the Charging Station itself (the grid connection) SHALL be reported. If omitted, all installed charging profiles SHALL be reported.
request_id: i64Reference identification that is to be used by the Charging Station in the <<reportchargingprofilesrequest, ReportChargingProfilesRequest>> when provided.