pub struct NotifyCustomerInformationRequest<const NOTIFY_CUSTOMER_INFORMATION_REQUEST_GENERATED_AT_CAP: usize = 1024> {
pub custom_data: Option<CustomData>,
pub data: String<512usize>,
pub generated_at: String<NOTIFY_CUSTOMER_INFORMATION_REQUEST_GENERATED_AT_CAP>,
pub request_id: i64,
pub seq_no: i64,
pub tbc: Option<bool>,
}Fields
custom_data: Option<CustomData>data: String<512usize>(Part of) the requested data. No format specified in which the data is returned. Should be human readable.
generated_at: String<NOTIFY_CUSTOMER_INFORMATION_REQUEST_GENERATED_AT_CAP>Timestamp of the moment this message was generated at the Charging Station.
request_id: i64The Id of the request.
seq_no: i64Sequence number of this message. First message starts at 0.
tbc: Option<bool>“to be continued” indicator. Indicates whether another part of the monitoringData follows in an upcoming notifyMonitoringReportRequest message. Default value when omitted is false.