TransactionEventRequest

Struct TransactionEventRequest 

pub struct TransactionEventRequest<const ID_TOKEN_ADDITIONAL_INFO_CAP: usize = 16, const TRANSACTION_EVENT_REQUEST_METER_VALUE_CAP: usize = 16, const METER_VALUE_SAMPLED_VALUE_CAP: usize = 16, const METER_VALUE_TIMESTAMP_CAP: usize = 1024, const TRANSACTION_EVENT_REQUEST_TIMESTAMP_CAP: usize = 1024> {
Show 13 fields pub cable_max_current: Option<i64>, pub custom_data: Option<CustomData>, pub event_type: TransactionEventEnum, pub evse: Option<EVSE>, pub id_token: Option<IdToken<ID_TOKEN_ADDITIONAL_INFO_CAP>>, pub meter_value: Option<Vec<MeterValue<METER_VALUE_SAMPLED_VALUE_CAP, METER_VALUE_TIMESTAMP_CAP>, TRANSACTION_EVENT_REQUEST_METER_VALUE_CAP>>, pub number_of_phases_used: Option<i64>, pub offline: Option<bool>, pub reservation_id: Option<i64>, pub seq_no: i64, pub timestamp: String<TRANSACTION_EVENT_REQUEST_TIMESTAMP_CAP>, pub transaction_info: Transaction, pub trigger_reason: TriggerReasonEnum,
}

Fields

cable_max_current: Option<i64>

The maximum current of the connected cable in Ampere (A).

custom_data: Option<CustomData>event_type: TransactionEventEnumevse: Option<EVSE>id_token: Option<IdToken<ID_TOKEN_ADDITIONAL_INFO_CAP>>meter_value: Option<Vec<MeterValue<METER_VALUE_SAMPLED_VALUE_CAP, METER_VALUE_TIMESTAMP_CAP>, TRANSACTION_EVENT_REQUEST_METER_VALUE_CAP>>number_of_phases_used: Option<i64>

If the Charging Station is able to report the number of phases used, then it SHALL provide it. When omitted the CSMS may be able to determine the number of phases used via device management.

offline: Option<bool>

Indication that this transaction event happened when the Charging Station was offline. Default = false, meaning: the event occurred when the Charging Station was online.

reservation_id: Option<i64>

This contains the Id of the reservation that terminates as a result of this transaction.

seq_no: i64

Incremental sequence number, helps with determining if all messages of a transaction have been received.

timestamp: String<TRANSACTION_EVENT_REQUEST_TIMESTAMP_CAP>

The date and time at which this transaction event occurred.

transaction_info: Transactiontrigger_reason: TriggerReasonEnum