OCPPInterfaceEnum

Enum OCPPInterfaceEnum 

pub enum OCPPInterfaceEnum {
    Wired0,
    Wired1,
    Wired2,
    Wired3,
    Wireless0,
    Wireless1,
    Wireless2,
    Wireless3,
    Any,
}
Applicable Network Interface. Charging Station is allowed to use a different network interface to connect if the given one does not work.

Variants



Wired0



Wired1



Wired2



Wired3



Wireless0



Wireless1



Wireless2



Wireless3



Any