OCPPVersionEnum

Enum OCPPVersionEnum 

pub enum OCPPVersionEnum {
    OCPP12,
    OCPP15,
    OCPP16,
    OCPP20,
    OCPP201,
    OCPP21,
}
(2.1) This field is ignored, since the OCPP version to use is determined during the websocket handshake. The field is only kept for backwards compatibility with the OCPP 2.0.1 JSON schema.

Variants



OCPP12



OCPP15



OCPP16



OCPP20



OCPP201



OCPP21