pub struct AdditionalInfo<CustomDataType = NoCustomData> {
pub additional_id_token: String<255usize>,
pub custom_data: Option<CustomDataType>,
pub type: String<50usize>,
}Expand description
Contains a case insensitive identifier to use for the authorization and the type of authorization to support multiple forms of identifiers.
Fields
additional_id_token: String<255usize>(2.1) This field specifies the additional IdToken.
custom_data: Option<CustomDataType>type: String<50usize>additionalInfo can be used to send extra information to CSMS in addition to the regular authorization with IdToken. AdditionalInfo contains one or more custom types, which need to be agreed upon by all parties involved. When the type is not supported, the CSMS/Charging Station MAY ignore the additionalInfo.