pub struct ChargingProfileCriterion<const CHARGING_PROFILE_CRITERION_CHARGING_PROFILE_ID_CAP: usize = 16> {
pub charging_limit_source: Option<Vec<String<20usize>, 4usize>>,
pub charging_profile_id: Option<Vec<i64, CHARGING_PROFILE_CRITERION_CHARGING_PROFILE_ID_CAP>>,
pub charging_profile_purpose: Option<ChargingProfilePurposeEnum>,
pub custom_data: Option<CustomData>,
pub stack_level: Option<i64>,
}Expand description
A ChargingProfileCriterionType is a filter for charging profiles to be selected by a GetChargingProfilesRequest.
Fields
charging_limit_source: Option<Vec<String<20usize>, 4usize>>For which charging limit sources, charging profiles SHALL be reported. If omitted, the Charging Station SHALL not filter on chargingLimitSource. Values defined in Appendix as ChargingLimitSourceEnumStringType.
charging_profile_id: Option<Vec<i64, CHARGING_PROFILE_CRITERION_CHARGING_PROFILE_ID_CAP>>List of all the chargingProfileIds requested. Any ChargingProfile that matches one of these profiles will be reported. If omitted, the Charging Station SHALL not filter on chargingProfileId. This field SHALL NOT contain more ids than set in <<configkey-charging-profile-entries,ChargingProfileEntries.maxLimit>>
charging_profile_purpose: Option<ChargingProfilePurposeEnum>custom_data: Option<CustomData>stack_level: Option<i64>Value determining level in hierarchy stack of profiles. Higher values have precedence over lower values. Lowest level is 0.