pub struct DERChargingParameters<const D_E_R_CHARGING_PARAMETERS_EV_ISLANDING_DETECTION_METHOD_CAP: usize = 16, const D_E_R_CHARGING_PARAMETERS_EV_SUPPORTED_D_E_R_CONTROL_CAP: usize = 16> {Show 42 fields
pub custom_data: Option<CustomData>,
pub ev_duration_level1_d_c_injection: Option<f64>,
pub ev_duration_level2_d_c_injection: Option<f64>,
pub ev_inverter_hw_version: Option<String<50usize>>,
pub ev_inverter_manufacturer: Option<String<50usize>>,
pub ev_inverter_model: Option<String<50usize>>,
pub ev_inverter_serial_number: Option<String<50usize>>,
pub ev_inverter_sw_version: Option<String<50usize>>,
pub ev_islanding_detection_method: Option<Vec<IslandingDetectionEnum, D_E_R_CHARGING_PARAMETERS_EV_ISLANDING_DETECTION_METHOD_CAP>>,
pub ev_islanding_trip_time: Option<f64>,
pub ev_maximum_level1_d_c_injection: Option<f64>,
pub ev_maximum_level2_d_c_injection: Option<f64>,
pub ev_over_excited_max_discharge_power: Option<f64>,
pub ev_over_excited_power_factor: Option<f64>,
pub ev_reactive_susceptance: Option<f64>,
pub ev_session_total_discharge_energy_available: Option<f64>,
pub ev_supported_d_e_r_control: Option<Vec<DERControlEnum, D_E_R_CHARGING_PARAMETERS_EV_SUPPORTED_D_E_R_CONTROL_CAP>>,
pub ev_under_excited_max_discharge_power: Option<f64>,
pub ev_under_excited_power_factor: Option<f64>,
pub max_apparent_power: Option<f64>,
pub max_charge_apparent_power: Option<f64>,
pub max_charge_apparent_power_l2: Option<f64>,
pub max_charge_apparent_power_l3: Option<f64>,
pub max_charge_reactive_power: Option<f64>,
pub max_charge_reactive_power_l2: Option<f64>,
pub max_charge_reactive_power_l3: Option<f64>,
pub max_discharge_apparent_power: Option<f64>,
pub max_discharge_apparent_power_l2: Option<f64>,
pub max_discharge_apparent_power_l3: Option<f64>,
pub max_discharge_reactive_power: Option<f64>,
pub max_discharge_reactive_power_l2: Option<f64>,
pub max_discharge_reactive_power_l3: Option<f64>,
pub max_nominal_voltage: Option<f64>,
pub min_charge_reactive_power: Option<f64>,
pub min_charge_reactive_power_l2: Option<f64>,
pub min_charge_reactive_power_l3: Option<f64>,
pub min_discharge_reactive_power: Option<f64>,
pub min_discharge_reactive_power_l2: Option<f64>,
pub min_discharge_reactive_power_l3: Option<f64>,
pub min_nominal_voltage: Option<f64>,
pub nominal_voltage: Option<f64>,
pub nominal_voltage_offset: Option<f64>,
}Expand description
(2.1) DERChargingParametersType is used in ChargingNeedsType during an ISO 15118-20 session for AC_BPT_DER to report the inverter settings related to DER control that were agreed between EVSE and EV.
Fields starting with “ev” contain values from the EV. Other fields contain a value that is supported by both EV and EVSE.
DERChargingParametersType type is only relevant in case of an ISO 15118-20 AC_BPT_DER/AC_DER charging session.
NOTE: All these fields have values greater or equal to zero (i.e. are non-negative)
Fields
custom_data: Option<CustomData>ev_duration_level1_d_c_injection: Option<f64>Maximum allowed duration of DC injection at level 1 charging. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVDurationLevel1DCInjection
ev_duration_level2_d_c_injection: Option<f64>Maximum allowed duration of DC injection at level 2 charging. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVDurationLevel2DCInjection
ev_inverter_hw_version: Option<String<50usize>>Hardware version of EV inverter. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVInverterHwVersion
ev_inverter_manufacturer: Option<String<50usize>>Manufacturer of the EV inverter. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVInverterManufacturer
ev_inverter_model: Option<String<50usize>>Model name of the EV inverter. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVInverterModel
ev_inverter_serial_number: Option<String<50usize>>Serial number of the EV inverter. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVInverterSerialNumber
ev_inverter_sw_version: Option<String<50usize>>Software version of EV inverter. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVInverterSwVersion
ev_islanding_detection_method: Option<Vec<IslandingDetectionEnum, D_E_R_CHARGING_PARAMETERS_EV_ISLANDING_DETECTION_METHOD_CAP>>Type of islanding detection method. Only mandatory when islanding detection is required at the site, as set in the ISO 15118 Service Details configuration. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVIslandingDetectionMethod
ev_islanding_trip_time: Option<f64>Time after which EV will trip if an island has been detected. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVIslandingTripTime
ev_maximum_level1_d_c_injection: Option<f64>Maximum injected DC current allowed at level 1 charging. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMaximumLevel1DCInjection
ev_maximum_level2_d_c_injection: Option<f64>Maximum injected DC current allowed at level 2 charging. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMaximumLevel2DCInjection
ev_over_excited_max_discharge_power: Option<f64>Rated maximum injected active power by EV, at specified over-excited power factor (overExcitedPowerFactor). + It can also be defined as the rated maximum discharge power at the rated minimum injected reactive power value. This means that if the EV is providing reactive power support, and it is requested to discharge at max power (e.g. to satisfy an EMS request), the EV may override the request and discharge up to overExcitedMaximumDischargePower to meet the minimum reactive power requirements. + Corresponds to the WOvPF attribute in IEC 61850. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVOverExcitedMaximumDischargePower
ev_over_excited_power_factor: Option<f64>EV power factor when injecting (over excited) the minimum reactive power. + Corresponds to the OvPF attribute in IEC 61850. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVOverExcitedPowerFactor
ev_reactive_susceptance: Option<f64>Measure of the susceptibility of the circuit to reactance, in Siemens (S). + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVReactiveSusceptance
ev_session_total_discharge_energy_available: Option<f64>Total energy value, in Wh, that EV is allowed to provide during the entire V2G session. The value is independent of the V2X Cycling area. Once this value reaches the value of 0, the EV may block any attempt to discharge in order to protect the battery health. ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVSessionTotalDischargeEnergyAvailable
ev_supported_d_e_r_control: Option<Vec<DERControlEnum, D_E_R_CHARGING_PARAMETERS_EV_SUPPORTED_D_E_R_CONTROL_CAP>>DER control functions supported by EV. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType:DERControlFunctions (bitmap)
ev_under_excited_max_discharge_power: Option<f64>Rated maximum injected active power by EV supported at specified under-excited power factor (EVUnderExcitedPowerFactor). + It can also be defined as the rated maximum dischargePower at the rated minimum absorbed reactive power value. This means that if the EV is providing reactive power support, and it is requested to discharge at max power (e.g. to satisfy an EMS request), the EV may override the request and discharge up to underExcitedMaximumDischargePower to meet the minimum reactive power requirements. + This corresponds to the WUnPF attribute in the IEC 61850. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVUnderExcitedMaximumDischargePower
ev_under_excited_power_factor: Option<f64>EV power factor when injecting (under excited) the minimum reactive power. + Corresponds to the OvPF attribute in IEC 61850. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVUnderExcitedPowerFactor
max_apparent_power: Option<f64>Rated maximum total apparent power, defined by min(EV, EVSE) in va. Corresponds to the VAMaxRtg in IEC 61850. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMaximumApparentPower
max_charge_apparent_power: Option<f64>Rated maximum absorbed apparent power, defined by min(EV, EVSE) in va. + This field represents the sum of all phases, unless values are provided for L2 and L3, in which case this field represents phase L1. + Corresponds to the ChaVAMaxRtg in IEC 61850. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMaximumChargeApparentPower
max_charge_apparent_power_l2: Option<f64>Rated maximum absorbed apparent power on phase L2, defined by min(EV, EVSE) in va. Corresponds to the ChaVAMaxRtg in IEC 61850. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMaximumChargeApparentPower_L2
max_charge_apparent_power_l3: Option<f64>Rated maximum absorbed apparent power on phase L3, defined by min(EV, EVSE) in va. Corresponds to the ChaVAMaxRtg in IEC 61850. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMaximumChargeApparentPower_L3
max_charge_reactive_power: Option<f64>Rated maximum absorbed reactive power, defined by min(EV, EVSE), in vars. + This field represents the sum of all phases, unless values are provided for L2 and L3, in which case this field represents phase L1. + Corresponds to the AvarMax attribute in the IEC 61850. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMaximumChargeReactivePower
max_charge_reactive_power_l2: Option<f64>Rated maximum absorbed reactive power, defined by min(EV, EVSE), in vars on phase L2. + Corresponds to the AvarMax attribute in the IEC 61850. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMaximumChargeReactivePower_L2
max_charge_reactive_power_l3: Option<f64>Rated maximum absorbed reactive power, defined by min(EV, EVSE), in vars on phase L3. + Corresponds to the AvarMax attribute in the IEC 61850. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMaximumChargeReactivePower_L3
max_discharge_apparent_power: Option<f64>Rated maximum injected apparent power, defined by min(EV, EVSE) in va. + This field represents the sum of all phases, unless values are provided for L2 and L3, in which case this field represents phase L1. + Corresponds to the DisVAMaxRtg in IEC 61850. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMaximumDischargeApparentPower
max_discharge_apparent_power_l2: Option<f64>Rated maximum injected apparent power on phase L2, defined by min(EV, EVSE) in va. + Corresponds to the DisVAMaxRtg in IEC 61850. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMaximumDischargeApparentPower_L2
max_discharge_apparent_power_l3: Option<f64>Rated maximum injected apparent power on phase L3, defined by min(EV, EVSE) in va. + Corresponds to the DisVAMaxRtg in IEC 61850. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMaximumDischargeApparentPower_L3
max_discharge_reactive_power: Option<f64>Rated maximum injected reactive power, defined by min(EV, EVSE), in vars. + This field represents the sum of all phases, unless values are provided for L2 and L3, in which case this field represents phase L1. + Corresponds to the IvarMax attribute in the IEC 61850. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMaximumDischargeReactivePower
max_discharge_reactive_power_l2: Option<f64>Rated maximum injected reactive power, defined by min(EV, EVSE), in vars on phase L2. + Corresponds to the IvarMax attribute in the IEC 61850. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMaximumDischargeReactivePower_L2
max_discharge_reactive_power_l3: Option<f64>Rated maximum injected reactive power, defined by min(EV, EVSE), in vars on phase L3. + Corresponds to the IvarMax attribute in the IEC 61850. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMaximumDischargeReactivePower_L3
max_nominal_voltage: Option<f64>Maximum AC rms voltage, as defined by min(EV, EVSE) to operate with. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMaximumNominalVoltage
min_charge_reactive_power: Option<f64>Rated minimum absorbed reactive power, defined by max(EV, EVSE), in vars. + This field represents the sum of all phases, unless values are provided for L2 and L3, in which case this field represents phase L1. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMinimumChargeReactivePower
min_charge_reactive_power_l2: Option<f64>Rated minimum absorbed reactive power, defined by max(EV, EVSE), in vars on phase L2. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMinimumChargeReactivePower_L2
min_charge_reactive_power_l3: Option<f64>Rated minimum absorbed reactive power, defined by max(EV, EVSE), in vars on phase L3. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMinimumChargeReactivePower_L3
min_discharge_reactive_power: Option<f64>Rated minimum injected reactive power, defined by max(EV, EVSE), in vars. + This field represents the sum of all phases, unless values are provided for L2 and L3, in which case this field represents phase L1. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMinimumDischargeReactivePower
min_discharge_reactive_power_l2: Option<f64>Rated minimum injected reactive power, defined by max(EV, EVSE), in var on phase L2. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMinimumDischargeReactivePower_L2
min_discharge_reactive_power_l3: Option<f64>Rated minimum injected reactive power, defined by max(EV, EVSE), in var on phase L3. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMinimumDischargeReactivePower_L3
min_nominal_voltage: Option<f64>Minimum AC rms voltage, as defined by max(EV, EVSE) to operate with. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVMinimumNominalVoltage
nominal_voltage: Option<f64>Line voltage supported by EVSE and EV. ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVNominalVoltage
nominal_voltage_offset: Option<f64>The nominal AC voltage (rms) offset between the Charging Station’s electrical connection point and the utility’s point of common coupling. + ISO 15118-20: DER_BPT_AC_CPDReqEnergyTransferModeType: EVNominalVoltageOffset