pub struct DERCurve<CustomDataType = NoCustomData> {
pub curve_data: Vec<DERCurvePoints<CustomDataType>, 10usize>,
pub custom_data: Option<CustomDataType>,
pub duration: Option<f64>,
pub hysteresis: Option<Hysteresis<CustomDataType>>,
pub priority: i64,
pub reactive_power_params: Option<ReactivePowerParams<CustomDataType>>,
pub response_time: Option<f64>,
pub start_time: Option<OcppTimestamp>,
pub voltage_params: Option<VoltageParams<CustomDataType>>,
pub y_unit: DERUnitEnum,
}Fields
curve_data: Vec<DERCurvePoints<CustomDataType>, 10usize>custom_data: Option<CustomDataType>duration: Option<f64>Duration in seconds that this curve will be active. Only absent when default is true.
hysteresis: Option<Hysteresis<CustomDataType>>priority: i64Priority of curve (0=highest)
reactive_power_params: Option<ReactivePowerParams<CustomDataType>>response_time: Option<f64>Open loop response time, the time to ramp up to 90% of the new target in response to the change in voltage, in seconds. A value of 0 is used to mean no limit. When not present, the device should follow its default behavior.
start_time: Option<OcppTimestamp>Point in time when this curve will become activated. Only absent when default is true.
voltage_params: Option<VoltageParams<CustomDataType>>y_unit: DERUnitEnumTrait Implementations
Sourceimpl<'de, CustomDataType> Deserialize<'de> for DERCurve<CustomDataType>where
CustomDataType: Deserialize<'de>,
impl<'de, CustomDataType> Deserialize<'de> for DERCurve<CustomDataType>where
CustomDataType: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<CustomDataType: PartialEq> StructuralPartialEq for DERCurve<CustomDataType>