pub struct DERCurve<const D_E_R_CURVE_START_TIME_CAP: usize = 1024> {
pub curve_data: Vec<DERCurvePoints, 10usize>,
pub custom_data: Option<CustomData>,
pub duration: Option<f64>,
pub hysteresis: Option<Hysteresis>,
pub priority: i64,
pub reactive_power_params: Option<ReactivePowerParams>,
pub response_time: Option<f64>,
pub start_time: Option<String<D_E_R_CURVE_START_TIME_CAP>>,
pub voltage_params: Option<VoltageParams>,
pub y_unit: DERUnitEnum,
}Fields
curve_data: Vec<DERCurvePoints, 10usize>custom_data: Option<CustomData>duration: Option<f64>Duration in seconds that this curve will be active. Only absent when default is true.
hysteresis: Option<Hysteresis>priority: i64Priority of curve (0=highest)
reactive_power_params: Option<ReactivePowerParams>response_time: Option<f64>Open loop response time, the time to ramp up to 90% of the new target in response to the change in voltage, in seconds. A value of 0 is used to mean no limit. When not present, the device should follow its default behavior.
start_time: Option<String<D_E_R_CURVE_START_TIME_CAP>>Point in time when this curve will become activated. Only absent when default is true.
voltage_params: Option<VoltageParams>y_unit: DERUnitEnumTrait Implementations
Sourceimpl<const D_E_R_CURVE_START_TIME_CAP: usize> PartialEq for DERCurve<D_E_R_CURVE_START_TIME_CAP>
impl<const D_E_R_CURVE_START_TIME_CAP: usize> PartialEq for DERCurve<D_E_R_CURVE_START_TIME_CAP>
impl<const D_E_R_CURVE_START_TIME_CAP: usize> StructuralPartialEq for DERCurve<D_E_R_CURVE_START_TIME_CAP>