EVPriceRule

Struct EVPriceRule 

pub struct EVPriceRule {
    pub custom_data: Option<CustomData>,
    pub energy_fee: f64,
    pub power_range_start: f64,
}
(2.1) An entry in price schedule over time for which EV is willing to discharge.

Fields

custom_data: Option<CustomData>energy_fee: f64

Cost per kWh.

power_range_start: f64

The EnergyFee applies between this value and the value of the PowerRangeStart of the subsequent EVPriceRule. If the power is below this value, the EnergyFee of the previous EVPriceRule applies. Negative values are used for discharging.