pub struct EventData<const EVENT_DATA_TIMESTAMP_CAP: usize = 1024> {Show 15 fields
pub actual_value: String<2500usize>,
pub cause: Option<i64>,
pub cleared: Option<bool>,
pub component: Component,
pub custom_data: Option<CustomData>,
pub event_id: i64,
pub event_notification_type: EventNotificationEnum,
pub severity: Option<i64>,
pub tech_code: Option<String<50usize>>,
pub tech_info: Option<String<500usize>>,
pub timestamp: String<EVENT_DATA_TIMESTAMP_CAP>,
pub transaction_id: Option<String<36usize>>,
pub trigger: EventTriggerEnum,
pub variable: Variable,
pub variable_monitoring_id: Option<i64>,
}Expand description
Class to report an event notification for a component-variable.
Fields
actual_value: String<2500usize>Actual value (attributeType Actual) of the variable.
The Configuration Variable <<configkey-reporting-value-size,ReportingValueSize>> can be used to limit GetVariableResult.attributeValue, VariableAttribute.value and EventData.actualValue. The max size of these values will always remain equal.
cause: Option<i64>Refers to the Id of an event that is considered to be the cause for this event.
cleared: Option<bool>Cleared is set to true to report the clearing of a monitored situation, i.e. a ‘return to normal’.
component: Componentcustom_data: Option<CustomData>event_id: i64Identifies the event. This field can be referred to as a cause by other events.
event_notification_type: EventNotificationEnumseverity: Option<i64>(2.1) Severity associated with the monitor in variableMonitoringId or with the hardwired notification.
tech_code: Option<String<50usize>>Technical (error) code as reported by component.
tech_info: Option<String<500usize>>Technical detail information as reported by component.
timestamp: String<EVENT_DATA_TIMESTAMP_CAP>Timestamp of the moment the report was generated.
transaction_id: Option<String<36usize>>If an event notification is linked to a specific transaction, this field can be used to specify its transactionId.
trigger: EventTriggerEnumvariable: Variablevariable_monitoring_id: Option<i64>Identifies the VariableMonitoring which triggered the event.