pub struct FixedVar<const FIXED_VAR_START_TIME_CAP: usize = 1024> {
pub custom_data: Option<CustomData>,
pub duration: Option<f64>,
pub priority: i64,
pub setpoint: f64,
pub start_time: Option<String<FIXED_VAR_START_TIME_CAP>>,
pub unit: DERUnitEnum,
}Fields
custom_data: Option<CustomData>duration: Option<f64>Duration in seconds that this setting is active.
priority: i64Priority of setting (0=highest)
setpoint: f64The value specifies a target var output interpreted as a signed percentage (-100 to 100). A negative value refers to charging, whereas a positive one refers to discharging. The value type is determined by the unit field.
start_time: Option<String<FIXED_VAR_START_TIME_CAP>>Time when this setting becomes active.
unit: DERUnitEnumTrait Implementations
impl<const FIXED_VAR_START_TIME_CAP: usize> StructuralPartialEq for FixedVar<FIXED_VAR_START_TIME_CAP>