pub struct Hysteresis {
pub custom_data: Option<CustomData>,
pub hysteresis_delay: Option<f64>,
pub hysteresis_gradient: Option<f64>,
pub hysteresis_high: Option<f64>,
pub hysteresis_low: Option<f64>,
}Fields
custom_data: Option<CustomData>hysteresis_delay: Option<f64>Delay in seconds, once grid parameter within HysteresisLow and HysteresisHigh, for the EV to return to normal operation after a grid event.
hysteresis_gradient: Option<f64>Set default rate of change (ramp rate %/s) for the EV to return to normal operation after a grid event
hysteresis_high: Option<f64>High value for return to normal operation after a grid event, in absolute value. This value adopts the same unit as defined by yUnit
hysteresis_low: Option<f64>Low value for return to normal operation after a grid event, in absolute value. This value adopts the same unit as defined by yUnit