pub struct IdTokenInfo<CustomDataType = NoCustomData> {
pub cache_expiry_date_time: Option<OcppTimestamp>,
pub charging_priority: Option<i64>,
pub custom_data: Option<CustomDataType>,
pub evse_id: Option<Vec<i64>>,
pub group_id_token: Option<IdToken<CustomDataType>>,
pub language1: Option<String<8usize>>,
pub language2: Option<String<8usize>>,
pub personal_message: Option<MessageContent<CustomDataType>>,
pub status: AuthorizationStatusEnum,
}Expand description
Contains status information about an identifier. It is advised to not stop charging for a token that expires during charging, as ExpiryDate is only used for caching purposes. If ExpiryDate is not given, the status has no end date.
Fields
cache_expiry_date_time: Option<OcppTimestamp>Date and Time after which the token must be considered invalid.
charging_priority: Option<i64>Priority from a business point of view. Default priority is 0, The range is from -9 to 9. Higher values indicate a higher priority. The chargingPriority in <<transactioneventresponse,TransactionEventResponse>> overrules this one.
custom_data: Option<CustomDataType>evse_id: Option<Vec<i64>>Only used when the IdToken is only valid for one or more specific EVSEs, not for the entire Charging Station.
group_id_token: Option<IdToken<CustomDataType>>language1: Option<String<8usize>>Preferred user interface language of identifier user. Contains a language code as defined in <<ref-RFC5646,[RFC5646]>>.
language2: Option<String<8usize>>Second preferred user interface language of identifier user. Don’t use when language1 is omitted, has to be different from language1. Contains a language code as defined in <<ref-RFC5646,[RFC5646]>>.
personal_message: Option<MessageContent<CustomDataType>>status: AuthorizationStatusEnumTrait Implementations
Sourceimpl<CustomDataType: Clone> Clone for IdTokenInfo<CustomDataType>
impl<CustomDataType: Clone> Clone for IdTokenInfo<CustomDataType>
Sourcefn clone(&self) -> IdTokenInfo<CustomDataType>
fn clone(&self) -> IdTokenInfo<CustomDataType>
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more