MeterValue

Struct MeterValue 

pub struct MeterValue<const METER_VALUE_SAMPLED_VALUE_CAP: usize = 16, const METER_VALUE_TIMESTAMP_CAP: usize = 1024> {
    pub custom_data: Option<CustomData>,
    pub sampled_value: Vec<SampledValue, METER_VALUE_SAMPLED_VALUE_CAP>,
    pub timestamp: String<METER_VALUE_TIMESTAMP_CAP>,
}
Collection of one or more sampled values in MeterValuesRequest and TransactionEvent. All sampled values in a MeterValue are sampled at the same point in time.

Fields

custom_data: Option<CustomData>sampled_value: Vec<SampledValue, METER_VALUE_SAMPLED_VALUE_CAP>timestamp: String<METER_VALUE_TIMESTAMP_CAP>

Timestamp for measured value(s).