NetworkConnectionProfile

Struct NetworkConnectionProfile 

pub struct NetworkConnectionProfile {
    pub apn: Option<APN>,
    pub basic_auth_password: Option<String<64usize>>,
    pub custom_data: Option<CustomData>,
    pub identity: Option<String<48usize>>,
    pub message_timeout: i64,
    pub ocpp_csms_url: String<2000usize>,
    pub ocpp_interface: OCPPInterfaceEnum,
    pub ocpp_transport: OCPPTransportEnum,
    pub ocpp_version: Option<OCPPVersionEnum>,
    pub security_profile: i64,
    pub vpn: Option<VPN>,
}
The NetworkConnectionProfile defines the functional and technical parameters of a communication link.

Fields

apn: Option<APN>basic_auth_password: Option<String<64usize>>

(2.1) BasicAuthPassword to use for security profile 1 or 2.

custom_data: Option<CustomData>identity: Option<String<48usize>>

(2.1) Charging Station identity to be used as the basic authentication username.

message_timeout: i64

Duration in seconds before a message send by the Charging Station via this network connection times-out. The best setting depends on the underlying network and response times of the CSMS. If you are looking for a some guideline: use 30 seconds as a starting point.

ocpp_csms_url: String<2000usize>

URL of the CSMS(s) that this Charging Station communicates with, without the Charging Station identity part. + The SecurityCtrlr.Identity field is appended to ocppCsmsUrl to provide the full websocket URL.

ocpp_interface: OCPPInterfaceEnumocpp_transport: OCPPTransportEnumocpp_version: Option<OCPPVersionEnum>security_profile: i64

This field specifies the security profile used when connecting to the CSMS with this NetworkConnectionProfile.

vpn: Option<VPN>