pub struct PriceLevelSchedule<CustomDataType = NoCustomData> {
pub custom_data: Option<CustomDataType>,
pub number_of_price_levels: i64,
pub price_level_schedule_entries: Vec<PriceLevelScheduleEntry<CustomDataType>>,
pub price_schedule_description: Option<String<32usize>>,
pub price_schedule_id: i64,
pub time_anchor: OcppTimestamp,
}Expand description
The PriceLevelScheduleType is modeled after the same type that is defined in ISO 15118-20, such that if it is supplied by an EMSP as a signed EXI message, the conversion from EXI to JSON (in OCPP) and back to EXI (for ISO 15118-20) does not change the digest and therefore does not invalidate the signature.
Fields
custom_data: Option<CustomDataType>number_of_price_levels: i64Defines the overall number of distinct price level elements used across all PriceLevelSchedules.
price_level_schedule_entries: Vec<PriceLevelScheduleEntry<CustomDataType>>price_schedule_description: Option<String<32usize>>Description of the price schedule.
price_schedule_id: i64Unique ID of this price schedule.
time_anchor: OcppTimestampStarting point of this price schedule.