pub struct SignedMeterValue<CustomDataType = NoCustomData> {
pub custom_data: Option<CustomDataType>,
pub encoding_method: String<50usize>,
pub public_key: Option<String>,
pub signed_meter_data: String,
pub signing_method: Option<String<50usize>>,
}Expand description
Represent a signed version of the meter value.
Fields
custom_data: Option<CustomDataType>encoding_method: String<50usize>Format used by the energy meter to encode the meter data. For example: OCMF or EDL.
public_key: Option<String>(2.1) Base64 encoded, sending depends on configuration variable PublicKeyWithSignedMeterValue.
signed_meter_data: StringBase64 encoded, contains the signed data from the meter in the format specified in encodingMethod, which might contain more then just the meter value. It can contain information like timestamps, reference to a customer etc.
signing_method: Option<String<50usize>>(2.1) Method used to create the digital signature. Optional, if already included in signedMeterData. Standard values for this are defined in Appendix as SigningMethodEnumStringType.