pub struct TariffConditionsFixed<CustomDataType = NoCustomData> {
pub custom_data: Option<CustomDataType>,
pub day_of_week: Option<Vec<DayOfWeekEnum, 7usize>>,
pub end_time_of_day: Option<OcppTimeOfDay>,
pub evse_kind: Option<EvseKindEnum>,
pub payment_brand: Option<String<20usize>>,
pub payment_recognition: Option<String<20usize>>,
pub start_time_of_day: Option<OcppTimeOfDay>,
pub valid_from_date: Option<OcppDate>,
pub valid_to_date: Option<OcppDate>,
}Expand description
These conditions describe if a FixedPrice applies at start of the transaction.
When more than one restriction is set, they are to be treated as a logical AND. All need to be valid before this price is active.
NOTE: startTimeOfDay and endTimeOfDay are in local time, because it is the time in the tariff as it is shown to the EV driver at the Charging Station. A Charging Station will convert this to the internal time zone that it uses (which is recommended to be UTC, see section Generic chapter 3.1) when performing cost calculation.
Fields
custom_data: Option<CustomDataType>day_of_week: Option<Vec<DayOfWeekEnum, 7usize>>Day(s) of the week this is tariff applies.
end_time_of_day: Option<OcppTimeOfDay>End time of day in local time. Same syntax as startTimeOfDay. + If end time < start time then the period wraps around to the next day. + To stop at end of the day use: 00:00.
evse_kind: Option<EvseKindEnum>payment_brand: Option<String<20usize>>For which payment brand this (adhoc) tariff applies. Can be used to add a surcharge for certain payment brands. Based on value of additionalIdToken from idToken.additionalInfo.type = “PaymentBrand”.
payment_recognition: Option<String<20usize>>Type of adhoc payment, e.g. CC, Debit. Based on value of additionalIdToken from idToken.additionalInfo.type = “PaymentRecognition”.
start_time_of_day: Option<OcppTimeOfDay>Start time of day in local time. + Format as per RFC 3339: time-hour “:” time-minute + Must be in 24h format with leading zeros. Hour/Minute separator: “:” Regex: ([0-1][0-9]|2[0-3]):[0-5][0-9]
valid_from_date: Option<OcppDate>Start date in local time, for example: 2015-12-24. Valid from this day (inclusive). + Format as per RFC 3339: full-date +
Regex: ([12][0-9]{3})-(0[1-9]|1[0-2])-(0[1-9]|[12][0-9]|3[01])
valid_to_date: Option<OcppDate>End date in local time, for example: 2015-12-27. Valid until this day (exclusive). Same syntax as validFromDate.