pub struct Transaction {
pub charging_state: Option<ChargingStateEnum>,
pub custom_data: Option<CustomData>,
pub operation_mode: Option<OperationModeEnum>,
pub remote_start_id: Option<i64>,
pub stopped_reason: Option<ReasonEnum>,
pub tariff_id: Option<String<60usize>>,
pub time_spent_charging: Option<i64>,
pub transaction_id: String<36usize>,
pub transaction_limit: Option<TransactionLimit>,
}Fields
charging_state: Option<ChargingStateEnum>custom_data: Option<CustomData>operation_mode: Option<OperationModeEnum>remote_start_id: Option<i64>The ID given to remote start request (<<requeststarttransactionrequest, RequestStartTransactionRequest>>. This enables to CSMS to match the started transaction to the given start request.
stopped_reason: Option<ReasonEnum>tariff_id: Option<String<60usize>>(2.1) Id of tariff in use for transaction
time_spent_charging: Option<i64>Contains the total time that energy flowed from EVSE to EV during the transaction (in seconds). Note that timeSpentCharging is smaller or equal to the duration of the transaction.
transaction_id: String<36usize>This contains the Id of the transaction.
transaction_limit: Option<TransactionLimit>Trait Implementations
Sourceimpl Clone for Transaction
impl Clone for Transaction
Sourcefn clone(&self) -> Transaction
fn clone(&self) -> Transaction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Transaction
impl Debug for Transaction
Sourceimpl PartialEq for Transaction
impl PartialEq for Transaction
impl StructuralPartialEq for Transaction