V2XChargingParameters

Struct V2XChargingParameters 

pub struct V2XChargingParameters {
Show 25 fields pub custom_data: Option<CustomData>, pub ev_max_energy_request: Option<f64>, pub ev_max_v2_x_energy_request: Option<f64>, pub ev_min_energy_request: Option<f64>, pub ev_min_v2_x_energy_request: Option<f64>, pub ev_target_energy_request: Option<f64>, pub max_charge_current: Option<f64>, pub max_charge_power: Option<f64>, pub max_charge_power_l2: Option<f64>, pub max_charge_power_l3: Option<f64>, pub max_discharge_current: Option<f64>, pub max_discharge_power: Option<f64>, pub max_discharge_power_l2: Option<f64>, pub max_discharge_power_l3: Option<f64>, pub max_voltage: Option<f64>, pub min_charge_current: Option<f64>, pub min_charge_power: Option<f64>, pub min_charge_power_l2: Option<f64>, pub min_charge_power_l3: Option<f64>, pub min_discharge_current: Option<f64>, pub min_discharge_power: Option<f64>, pub min_discharge_power_l2: Option<f64>, pub min_discharge_power_l3: Option<f64>, pub min_voltage: Option<f64>, pub target_so_c: Option<i64>,
}
Charging parameters for ISO 15118-20, also supporting V2X charging/discharging.+ All values are greater or equal to zero, with the exception of EVMinEnergyRequest, EVMaxEnergyRequest, EVTargetEnergyRequest, EVMinV2XEnergyRequest and EVMaxV2XEnergyRequest.

Fields

custom_data: Option<CustomData>ev_max_energy_request: Option<f64>

Energy to maximum state of charge in Wh Relates to: ISO 15118-20: Dynamic/Scheduled_SEReqControlModeType: EVMaximumEnergyRequest

ev_max_v2_x_energy_request: Option<f64>

Energy (in Wh) to maximum state of charge for cycling (V2X) activity. Negative value indicates that current state of charge is above V2X range. Relates to: ISO 15118-20: Dynamic_SEReqControlModeType: EVMaximumV2XEnergyRequest

ev_min_energy_request: Option<f64>

Energy to minimum allowed state of charge in Wh Relates to: ISO 15118-20: Dynamic/Scheduled_SEReqControlModeType: EVMinimumEnergyRequest

ev_min_v2_x_energy_request: Option<f64>

Energy (in Wh) to minimum state of charge for cycling (V2X) activity. Positive value means that current state of charge is below V2X range. Relates to: ISO 15118-20: Dynamic_SEReqControlModeType: EVMinimumV2XEnergyRequest

ev_target_energy_request: Option<f64>

Energy to requested state of charge in Wh Relates to: ISO 15118-20: Dynamic/Scheduled_SEReqControlModeType: EVTargetEnergyRequest

max_charge_current: Option<f64>

Maximum charge current in A, defined by min(EV, EVSE) Relates to: ISO 15118-20: BPT_DC_CPDReqEnergyTransferModeType: EVMaximumChargeCurrent

max_charge_power: Option<f64>

Maximum charge (absorbed) power in W, defined by min(EV, EVSE) at unity power factor. + This field represents the sum of all phases, unless values are provided for L2 and L3, in which case this field represents phase L1. It corresponds to the ChaWMax attribute in the IEC 61850. It is usually equivalent to the rated apparent power of the EV when discharging (ChaVAMax) in IEC 61850. +

Relates to: ISO 15118-20: BPT_AC/DC_CPDReqEnergyTransferModeType: EVMaximumChargePower

max_charge_power_l2: Option<f64>

Maximum charge power on phase L2 in W, defined by min(EV, EVSE) Relates to: ISO 15118-20: BPT_AC/DC_CPDReqEnergyTransferModeType: EVMaximumChargePower_L2

max_charge_power_l3: Option<f64>

Maximum charge power on phase L3 in W, defined by min(EV, EVSE) Relates to: ISO 15118-20: BPT_AC/DC_CPDReqEnergyTransferModeType: EVMaximumChargePower_L3

max_discharge_current: Option<f64>

Maximum discharge current in A, defined by min(EV, EVSE). Value >= 0. Relates to: ISO 15118-20: BPT_DC_CPDReqEnergyTransferModeType: EVMaximumDischargeCurrent

max_discharge_power: Option<f64>

Maximum discharge (injected) power in W, defined by min(EV, EVSE) at unity power factor. Value >= 0. This field represents the sum of all phases, unless values are provided for L2 and L3, in which case this field represents phase L1. Relates to: ISO 15118-20: BPT_AC/DC_CPDReqEnergyTransferModeType: EVMaximumDischargePower

max_discharge_power_l2: Option<f64>

Maximum discharge power on phase L2 in W, defined by min(EV, EVSE). Value >= 0. Relates to: ISO 15118-20: BPT_AC/DC_CPDReqEnergyTransferModeType: EVMaximumDischargePowe_L2

max_discharge_power_l3: Option<f64>

Maximum discharge power on phase L3 in W, defined by min(EV, EVSE). Value >= 0. Relates to: ISO 15118-20: BPT_AC/DC_CPDReqEnergyTransferModeType: EVMaximumDischargePower_L3

max_voltage: Option<f64>

Maximum voltage in V, defined by min(EV, EVSE) Relates to: ISO 15118-20: BPT_DC_CPDReqEnergyTransferModeType: EVMaximumVoltage

min_charge_current: Option<f64>

Minimum charge current in A, defined by max(EV, EVSE) Relates to: ISO 15118-20: BPT_DC_CPDReqEnergyTransferModeType: EVMinimumChargeCurrent

min_charge_power: Option<f64>

Minimum charge power in W, defined by max(EV, EVSE). This field represents the sum of all phases, unless values are provided for L2 and L3, in which case this field represents phase L1. Relates to: ISO 15118-20: BPT_AC/DC_CPDReqEnergyTransferModeType: EVMinimumChargePower

min_charge_power_l2: Option<f64>

Minimum charge power on phase L2 in W, defined by max(EV, EVSE). Relates to: ISO 15118-20: BPT_AC/DC_CPDReqEnergyTransferModeType: EVMinimumChargePower_L2

min_charge_power_l3: Option<f64>

Minimum charge power on phase L3 in W, defined by max(EV, EVSE). Relates to: ISO 15118-20: BPT_AC/DC_CPDReqEnergyTransferModeType: EVMinimumChargePower_L3

min_discharge_current: Option<f64>

Minimum discharge current in A, defined by max(EV, EVSE). Value >= 0. Relates to: ISO 15118-20: BPT_DC_CPDReqEnergyTransferModeType: EVMinimumDischargeCurrent

min_discharge_power: Option<f64>

Minimum discharge (injected) power in W, defined by max(EV, EVSE) at unity power factor. Value >= 0. + This field represents the sum of all phases, unless values are provided for L2 and L3, in which case this field represents phase L1. + It corresponds to the WMax attribute in the IEC 61850. It is usually equivalent to the rated apparent power of the EV when discharging (VAMax attribute in the IEC 61850).

Relates to: ISO 15118-20: BPT_AC/DC_CPDReqEnergyTransferModeType: EVMinimumDischargePower

min_discharge_power_l2: Option<f64>

Minimum discharge power on phase L2 in W, defined by max(EV, EVSE). Value >= 0. Relates to: ISO 15118-20: BPT_AC/DC_CPDReqEnergyTransferModeType: EVMinimumDischargePower_L2

min_discharge_power_l3: Option<f64>

Minimum discharge power on phase L3 in W, defined by max(EV, EVSE). Value >= 0. Relates to: ISO 15118-20: BPT_AC/DC_CPDReqEnergyTransferModeType: EVMinimumDischargePower_L3

min_voltage: Option<f64>

Minimum voltage in V, defined by max(EV, EVSE) Relates to: ISO 15118-20: BPT_DC_CPDReqEnergyTransferModeType: EVMinimumVoltage

target_so_c: Option<i64>

Target state of charge at departure as percentage. Relates to: ISO 15118-20: BPT_DC_CPDReqEnergyTransferModeType: TargetSOC