Variable

Struct Variable 

pub struct Variable {
    pub custom_data: Option<CustomData>,
    pub instance: Option<String<50usize>>,
    pub name: String<50usize>,
}
Reference key to a component-variable.

Fields

custom_data: Option<CustomData>instance: Option<String<50usize>>

Name of instance in case the variable exists as multiple instances. Case Insensitive. strongly advised to use Camel Case.

name: String<50usize>

Name of the variable. Name should be taken from the list of standardized variable names whenever possible. Case Insensitive. strongly advised to use Camel Case.