pub struct VariableAttribute {
pub constant: Option<bool>,
pub custom_data: Option<CustomData>,
pub mutability: Option<MutabilityEnum>,
pub persistent: Option<bool>,
pub type: Option<AttributeEnum>,
pub value: Option<String<2500usize>>,
}Expand description
Attribute data of a variable.
Fields
constant: Option<bool>If true, value that will never be changed by the Charging Station at runtime. Default when omitted is false.
custom_data: Option<CustomData>mutability: Option<MutabilityEnum>persistent: Option<bool>If true, value will be persistent across system reboots or power down. Default when omitted is false.
type: Option<AttributeEnum>value: Option<String<2500usize>>Value of the attribute. May only be omitted when mutability is set to ‘WriteOnly’.
The Configuration Variable <<configkey-reporting-value-size,ReportingValueSize>> can be used to limit GetVariableResult.attributeValue, VariableAttribute.value and EventData.actualValue. The max size of these values will always remain equal.