GetChargingProfilesRequest

Struct GetChargingProfilesRequest 

pub struct GetChargingProfilesRequest<const CHARGING_PROFILE_CRITERION_CHARGING_PROFILE_ID_CAP: usize = 16> {
    pub charging_profile: ChargingProfileCriterion<CHARGING_PROFILE_CRITERION_CHARGING_PROFILE_ID_CAP>,
    pub custom_data: Option<CustomData>,
    pub evse_id: Option<i64>,
    pub request_id: i64,
}

Fields

charging_profile: ChargingProfileCriterion<CHARGING_PROFILE_CRITERION_CHARGING_PROFILE_ID_CAP>custom_data: Option<CustomData>evse_id: Option<i64>

For which EVSE installed charging profiles SHALL be reported. If 0, only charging profiles installed on the Charging Station itself (the grid connection) SHALL be reported. If omitted, all installed charging profiles SHALL be reported. + Reported charging profiles SHALL match the criteria in field chargingProfile.

request_id: i64

Reference identification that is to be used by the Charging Station in the <<reportchargingprofilesrequest, ReportChargingProfilesRequest>> when provided.