NotifySettlementRequest

Struct NotifySettlementRequest 

pub struct NotifySettlementRequest<const NOTIFY_SETTLEMENT_REQUEST_SETTLEMENT_TIME_CAP: usize = 1024> {
    pub custom_data: Option<CustomData>,
    pub psp_ref: String<255usize>,
    pub receipt_id: Option<String<50usize>>,
    pub receipt_url: Option<String<2000usize>>,
    pub settlement_amount: f64,
    pub settlement_time: String<NOTIFY_SETTLEMENT_REQUEST_SETTLEMENT_TIME_CAP>,
    pub status: PaymentStatusEnum,
    pub status_info: Option<String<500usize>>,
    pub transaction_id: Option<String<36usize>>,
    pub vat_company: Option<Address>,
    pub vat_number: Option<String<20usize>>,
}

Fields

custom_data: Option<CustomData>psp_ref: String<255usize>

The payment reference received from the payment terminal and is used as the value for idToken.

receipt_id: Option<String<50usize>>receipt_url: Option<String<2000usize>>

The receipt URL, to be used if the receipt is generated by the payment terminal or the CS.

settlement_amount: f64

The amount that was settled, or attempted to be settled (in case of failure).

settlement_time: String<NOTIFY_SETTLEMENT_REQUEST_SETTLEMENT_TIME_CAP>

The time when the settlement was done.

status: PaymentStatusEnumstatus_info: Option<String<500usize>>

Additional information from payment terminal/payment process.

transaction_id: Option<String<36usize>>

The transactionId that the settlement belongs to. Can be empty if the payment transaction is canceled prior to the start of the OCPP transaction.

vat_company: Option<Address>vat_number: Option<String<20usize>>

VAT number for a company receipt.