pub struct TransactionEventResponse<const ID_TOKEN_INFO_CACHE_EXPIRY_DATE_TIME_CAP: usize = 1024, const ID_TOKEN_INFO_EVSE_ID_CAP: usize = 16, const ID_TOKEN_ADDITIONAL_INFO_CAP: usize = 16> {
pub charging_priority: Option<i64>,
pub custom_data: Option<CustomData>,
pub id_token_info: Option<IdTokenInfo<ID_TOKEN_INFO_CACHE_EXPIRY_DATE_TIME_CAP, ID_TOKEN_INFO_EVSE_ID_CAP, ID_TOKEN_ADDITIONAL_INFO_CAP>>,
pub total_cost: Option<f64>,
pub transaction_limit: Option<TransactionLimit>,
pub updated_personal_message: Option<MessageContent>,
pub updated_personal_message_extra: Option<Vec<MessageContent, 4usize>>,
}Fields
charging_priority: Option<i64>Priority from a business point of view. Default priority is 0, The range is from -9 to 9. Higher values indicate a higher priority. The chargingPriority in <<transactioneventresponse,TransactionEventResponse>> is temporarily, so it may not be set in the <<cmn_idtokeninfotype,IdTokenInfoType>> afterwards. Also the chargingPriority in <<transactioneventresponse,TransactionEventResponse>> has a higher priority than the one in <<cmn_idtokeninfotype,IdTokenInfoType>>.
custom_data: Option<CustomData>id_token_info: Option<IdTokenInfo<ID_TOKEN_INFO_CACHE_EXPIRY_DATE_TIME_CAP, ID_TOKEN_INFO_EVSE_ID_CAP, ID_TOKEN_ADDITIONAL_INFO_CAP>>total_cost: Option<f64>When eventType of TransactionEventRequest is Updated, then this value contains the running cost. When eventType of TransactionEventRequest is Ended, then this contains the final total cost of this transaction, including taxes, in the currency configured with the Configuration Variable: Currency. Absence of this value does not imply that the transaction was free. To indicate a free transaction, the CSMS SHALL send a value of 0.00.
transaction_limit: Option<TransactionLimit>updated_personal_message: Option<MessageContent>updated_personal_message_extra: Option<Vec<MessageContent, 4usize>>Trait Implementations
Sourceimpl<const ID_TOKEN_INFO_CACHE_EXPIRY_DATE_TIME_CAP: usize, const ID_TOKEN_INFO_EVSE_ID_CAP: usize, const ID_TOKEN_ADDITIONAL_INFO_CAP: usize> Action for TransactionEventResponse<ID_TOKEN_INFO_CACHE_EXPIRY_DATE_TIME_CAP, ID_TOKEN_INFO_EVSE_ID_CAP, ID_TOKEN_ADDITIONAL_INFO_CAP>
Available on non-crate feature alloc only.
impl<const ID_TOKEN_INFO_CACHE_EXPIRY_DATE_TIME_CAP: usize, const ID_TOKEN_INFO_EVSE_ID_CAP: usize, const ID_TOKEN_ADDITIONAL_INFO_CAP: usize> Action for TransactionEventResponse<ID_TOKEN_INFO_CACHE_EXPIRY_DATE_TIME_CAP, ID_TOKEN_INFO_EVSE_ID_CAP, ID_TOKEN_ADDITIONAL_INFO_CAP>
alloc only.Sourceimpl<const ID_TOKEN_INFO_CACHE_EXPIRY_DATE_TIME_CAP: usize, const ID_TOKEN_INFO_EVSE_ID_CAP: usize, const ID_TOKEN_ADDITIONAL_INFO_CAP: usize> Clone for TransactionEventResponse<ID_TOKEN_INFO_CACHE_EXPIRY_DATE_TIME_CAP, ID_TOKEN_INFO_EVSE_ID_CAP, ID_TOKEN_ADDITIONAL_INFO_CAP>
impl<const ID_TOKEN_INFO_CACHE_EXPIRY_DATE_TIME_CAP: usize, const ID_TOKEN_INFO_EVSE_ID_CAP: usize, const ID_TOKEN_ADDITIONAL_INFO_CAP: usize> Clone for TransactionEventResponse<ID_TOKEN_INFO_CACHE_EXPIRY_DATE_TIME_CAP, ID_TOKEN_INFO_EVSE_ID_CAP, ID_TOKEN_ADDITIONAL_INFO_CAP>
Sourcefn clone(
&self,
) -> TransactionEventResponse<ID_TOKEN_INFO_CACHE_EXPIRY_DATE_TIME_CAP, ID_TOKEN_INFO_EVSE_ID_CAP, ID_TOKEN_ADDITIONAL_INFO_CAP>
fn clone( &self, ) -> TransactionEventResponse<ID_TOKEN_INFO_CACHE_EXPIRY_DATE_TIME_CAP, ID_TOKEN_INFO_EVSE_ID_CAP, ID_TOKEN_ADDITIONAL_INFO_CAP>
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more